@@ -8,10 +8,10 @@
 
 @interface DockTextField : NSTextField
 
-@property (nonatomic,retain) NSString *textToDisplay;
-@property (nonatomic,retain) NSColor *startColor;
-@property (nonatomic,retain) NSColor *endColor;
+@property (nonatomic, copy) NSString *textToDisplay;
+@property (nonatomic, copy) NSColor *startColor;
+@property (nonatomic, copy) NSColor *endColor;
 
-- (void)changeGradientColors:(NSColor*)startColor endColor:(NSColor*)endColor;
+- (void)changeGradientColors:(NSColor *)startColor endColor:(NSColor *)endColor;
 
 @end
