@@ -5,6 +5,11 @@
  It may be used under the terms of the GNU General Public License. */
 
 #import <Foundation/Foundation.h>
+#import "HBPresetCoding.h"
+
+NS_ASSUME_NONNULL_BEGIN
+
+@class HBAudioTrackPreset;
 
 typedef NS_ENUM(NSUInteger, HBAudioTrackSelectionBehavior) {
     HBAudioTrackSelectionBehaviorNone,
@@ -16,27 +21,36 @@ typedef NS_ENUM(NSUInteger, HBAudioTrackSelectionBehavior) {
  *  HBAudioSettings
  *  Stores the audio defaults settings.
  */
-@interface HBAudioDefaults : NSObject
+@interface HBAudioDefaults : NSObject <NSSecureCoding, NSCopying, HBPresetCoding>
 
 @property (nonatomic, readwrite) HBAudioTrackSelectionBehavior trackSelectionBehavior;
-@property (nonatomic, readwrite, retain) NSMutableArray *trackSelectionLanguages;
+@property (nonatomic, readwrite, strong) NSMutableArray<NSString *> *trackSelectionLanguages;
+@property (nonatomic, readwrite, strong) NSMutableArray<HBAudioTrackPreset *> *tracksArray;
 
-@property (nonatomic, readwrite, retain) NSMutableArray *tracksArray;
+/**
+ *  Adds a new track preset.
+ */
+- (void)addTrack;
 
 @property(nonatomic, readwrite) BOOL allowAACPassthru;
 @property(nonatomic, readwrite) BOOL allowAC3Passthru;
+@property(nonatomic, readwrite) BOOL allowEAC3Passthru;
 @property(nonatomic, readwrite) BOOL allowDTSHDPassthru;
 @property(nonatomic, readwrite) BOOL allowDTSPassthru;
 @property(nonatomic, readwrite) BOOL allowMP3Passthru;
+@property(nonatomic, readwrite) BOOL allowTrueHDPassthru;
+@property(nonatomic, readwrite) BOOL allowFLACPassthru;
 
 @property(nonatomic, readwrite) int encoderFallback;
 @property(nonatomic, readwrite) BOOL secondaryEncoderMode;
 
-@property(nonatomic, readonly) NSArray *audioEncoderFallbacks;
-
-- (void)applySettingsFromPreset:(NSDictionary *)preset;
-- (void)prepareAudioDefaultsForPreset:(NSMutableDictionary *)preset;
+@property(nonatomic, readonly) NSArray<NSString *> *audioEncoderFallbacks;
 
 - (void)validateEncoderFallbackForVideoContainer:(int)container;
+- (void)applyPreset:(HBPreset *)preset;
+
+@property (nonatomic, readwrite, weak, nullable) NSUndoManager *undo;
 
 @end
+
+NS_ASSUME_NONNULL_END
