@@ -35,12 +35,12 @@
                                        label: (NSString *)label
                                        image: (NSImage *)image;
 
-@property (assign) IBOutlet NSTokenField *formatTokenField;
-@property (assign) IBOutlet NSTokenField *builtInTokenField;
-@property (nonatomic, readonly) NSArray *buildInFormatTokens;
-@property (nonatomic, retain) NSArray *matches;
+@property (unsafe_unretained) IBOutlet NSTokenField *formatTokenField;
+@property (unsafe_unretained) IBOutlet NSTokenField *builtInTokenField;
+@property (nonatomic, readonly, strong) NSArray *buildInFormatTokens;
+@property (nonatomic, strong) NSArray *matches;
 
-@property (nonatomic, retain) HBLanguagesSelection *languages;
+@property (nonatomic, strong) HBLanguagesSelection *languages;
 
 @end
 
@@ -54,30 +54,36 @@
  */
 + (void)registerUserDefaults
 {
-    NSString *desktopDirectory =  [@"~/Desktop" stringByExpandingTildeInPath];
+    NSString *desktopDirectory = [NSSearchPathForDirectoriesInDomains(NSDesktopDirectory, NSUserDomainMask, YES) firstObject];
+    NSURL *desktopURL = [NSURL fileURLWithPath:desktopDirectory isDirectory:YES];
 
     [[NSUserDefaults standardUserDefaults] registerDefaults:@{
-        @"LaunchSourceBehavior":            @"Open Source",
+        @"HBShowOpenPanelAtLaunch":         @YES,
         @"DefaultLanguage":                 @"English",
         @"DefaultMpegExtension":            @"Auto",
         @"UseDvdNav":                       @"YES",
         @"HBDefaultPresetsDrawerShow":      @YES,
-        @"LastDestinationDirectory":        desktopDirectory,
-        @"LastSourceDirectory":             desktopDirectory,
+        // Archive the URL because they aren't supported in plist.
+        @"HBLastDestinationDirectory":      [NSKeyedArchiver archivedDataWithRootObject:desktopURL],
+        @"HBLastSourceDirectory":           [NSKeyedArchiver archivedDataWithRootObject:desktopURL],
         @"DefaultAutoNaming":               @NO,
-        @"AlertWhenDone":                   @"Alert Window",
+        @"HBAlertWhenDone":                 @(HBDoneActionNotification),
         @"AlertWhenDoneSound":              @"YES",
         @"LoggingLevel":                    @"1",
+        @"HBClearOldLogs":                  @YES,
         @"EncodeLogLocation":               @"NO",
         @"MinTitleScanSeconds":             @"10",
         @"PreviewsNumber":                  @"10",
-        @"Drawer Size":                     @"",
-        @"x264CqSliderFractional":          @"0.25",
-        @"AlertBuiltInPresetUpdate":        @"YES",
-        @"SendCompletedEncodeToApp":        @"MetaX",
+        @"x264CqSliderFractional":          @"0.50",
         @"HBShowAdvancedTab":               @NO,
-        @"HBAutoNamingFormat":              @[@"{Source}", @" ", @"{Title}"]
+        @"HBAutoNamingFormat":              @[@"{Source}", @" ", @"{Title}"],
+        @"HBDrawerSize":                    NSStringFromSize(NSMakeSize(184, 591))
         }];
+
+    // Overwrite the update check interval because previous versions
+    // could be set to a dayly check.
+    NSUInteger week = 60 * 60 * 24 * 7;
+    [[NSUserDefaults standardUserDefaults] setObject:@(week) forKey:@"SUScheduledCheckInterval"];
 }
 
 /**
@@ -86,20 +92,23 @@
  * Initializes the preferences controller by loading Preferences.nib file.
  *
  */
-- (id)init
+- (instancetype)init
 {
     if (self = [super initWithWindowNibName:@"Preferences"])
     {
         _languages = [[HBLanguagesSelection alloc] init];
-        NSAssert([self window], @"[HBPreferencesController init] window outlet is not connected in Preferences.nib");
     }
     return self;
 }
 
-- (void)dealloc
+- (void)showWindow:(id)sender
 {
-    [_languages release];
-    [super dealloc];
+    if (!self.window.isVisible)
+    {
+        [self.window center];
+    }
+
+    [super showWindow:sender];
 }
 
 /**
@@ -111,7 +120,7 @@
  */
 - (void) awakeFromNib
 {
-    NSToolbar * toolbar = [[[NSToolbar alloc] initWithIdentifier: @"Preferences Toolbar"] autorelease];
+    NSToolbar * toolbar = [[NSToolbar alloc] initWithIdentifier: @"Preferences Toolbar"];
     [toolbar setDelegate: self];
     [toolbar setAllowsUserCustomization: NO];
     [toolbar setDisplayMode: NSToolbarDisplayModeIconAndLabel];
@@ -122,7 +131,7 @@
     [self.formatTokenField setTokenizingCharacterSet:[NSCharacterSet characterSetWithCharactersInString:@"%%"]];
     [self.formatTokenField setCompletionDelay:0.2];
 
-    _buildInFormatTokens = [@[@"{Source}", @"{Title}", @"{Date}", @"{Time}", @"{Chapters}", @"{Quality/Bitrate}"] retain];
+    _buildInFormatTokens = @[@"{Source}", @"{Title}", @"{Date}", @"{Time}", @"{Chapters}", @"{Quality/Bitrate}"];
     [self.builtInTokenField setTokenizingCharacterSet:[NSCharacterSet characterSetWithCharactersInString:@"%%"]];
     [self.builtInTokenField setStringValue:[self.buildInFormatTokens componentsJoinedByString:@"%%"]];
 
@@ -175,13 +184,13 @@
 /*Opens the app browse window*/
 - (IBAction) browseSendToApp: (id) sender
 {
-    NSOpenPanel * panel;
-	
-    panel = [NSOpenPanel openPanel];
-    [panel setAllowsMultipleSelection: NO];
-    [panel setCanChooseFiles: YES];
-    [panel setCanChooseDirectories: NO ];
-    NSString * sendToAppDirectory;
+    NSOpenPanel *panel = [NSOpenPanel openPanel];
+    [panel setAllowsMultipleSelection:NO];
+    [panel setCanChooseFiles:YES];
+    [panel setCanChooseDirectories:NO];
+    [panel setAllowedFileTypes:@[@"app"]];
+
+    NSString *sendToAppDirectory;
 	if ([[NSUserDefaults standardUserDefaults] stringForKey:@"LastSendToAppDirectory"])
 	{
 		sendToAppDirectory = [[NSUserDefaults standardUserDefaults] stringForKey:@"LastSendToAppDirectory"];
@@ -196,13 +205,13 @@
         if (result == NSOKButton)
         {
             NSURL *sendToAppURL = [panel URL];
-            NSURL *sendToAppDirectory = [sendToAppURL URLByDeletingLastPathComponent];
-            [[NSUserDefaults standardUserDefaults] setObject:[sendToAppDirectory path] forKey:@"LastSendToAppDirectory"];
+            NSURL *sendToAppDirectoryURL = [sendToAppURL URLByDeletingLastPathComponent];
+            [[NSUserDefaults standardUserDefaults] setObject:[sendToAppDirectoryURL path] forKey:@"LastSendToAppDirectory"];
 
             NSString *sendToAppName = [[sendToAppURL lastPathComponent] stringByDeletingPathExtension];
             /* we set the name of the app to send to in the display field */
             [fSendEncodeToAppField setStringValue:sendToAppName];
-            [[NSUserDefaults standardUserDefaults] setObject:[fSendEncodeToAppField stringValue] forKey:@"SendCompletedEncodeToApp"];
+            [[NSUserDefaults standardUserDefaults] setObject:[fSendEncodeToAppField stringValue] forKey:@"HBSendToApp"];
         }
     }];
 }
@@ -211,7 +220,7 @@
 
 - (NSString *)tokenField:(NSTokenField *)tokenField displayStringForRepresentedObject:(id)representedObject
 {
-    if ([representedObject rangeOfString: @"{"].location == 0)
+    if ([representedObject rangeOfString: @"{"].location == 0 && [representedObject length] > 1)
     {
         return [(NSString *)representedObject substringWithRange:NSMakeRange(1, [(NSString*)representedObject length]-2)];
     }
@@ -274,44 +283,61 @@
 
 - (void) setPrefView: (id) sender
 {
-    NSView * view = fGeneralView;
-    if( sender )
+    NSView *view = fGeneralView;
+    if (sender)
     {
-        NSString * identifier = [sender itemIdentifier];
-        if( [identifier isEqualToString: TOOLBAR_AUDIO] )
+        NSString *identifier = [sender itemIdentifier];
+        if ([identifier isEqualToString:TOOLBAR_AUDIO])
+        {
             view = fAudioView;
-        else if( [identifier isEqualToString: TOOLBAR_ADVANCED] )
+        }
+        else if([identifier isEqualToString:TOOLBAR_ADVANCED])
+        {
             view = fAdvancedView;
-        else;
+        }
     }
 
-    NSWindow * window = [self window];
-    if( [window contentView] == view )
+    NSWindow *window =  self.window;
+    if (window.contentView == view)
+    {
         return;
+    }
 
-    NSRect windowRect = [window frame];
-    CGFloat difference = ( [view frame].size.height - [[window contentView] frame].size.height ) * [window userSpaceScaleFactor];
-    windowRect.origin.y -= difference;
-    windowRect.size.height += difference;
+    window.contentView = view;
 
-    [view setHidden: YES];
-    [window setContentView: view];
-    [window setFrame: windowRect display: YES animate: YES];
-    [view setHidden: NO];
+    if (window.isVisible)
+        {
+            view.hidden = YES;
 
-    //set title label
-    if( sender )
-        [window setTitle: [sender label]];
+            [NSAnimationContext runAnimationGroup:^(NSAnimationContext *context) {
+                if ([context respondsToSelector:@selector(setAllowsImplicitAnimation:)])
+                {
+                    context.allowsImplicitAnimation = YES;
+                }
+                [window layoutIfNeeded];
+
+            } completionHandler:^{
+                view.hidden = NO;
+            }];
+    }
+
+    // set title label
+    if (sender)
+    {
+        window.title = [sender label];
+    }
     else
     {
-        NSToolbar * toolbar = [window toolbar];
-        NSString * itemIdentifier = [toolbar selectedItemIdentifier];
-        for( NSToolbarItem * item in [toolbar items] )
-            if( [[item itemIdentifier] isEqualToString: itemIdentifier] )
+        NSToolbar *toolbar = window.toolbar;
+        NSString *itemIdentifier = toolbar.selectedItemIdentifier;
+        for (NSToolbarItem *item in toolbar.items)
+        {
+            if ([item.itemIdentifier isEqualToString:itemIdentifier])
             {
-                [window setTitle: [item label]];
+                window.title = item.label;
                 break;
             }
+        }
     }
 }
 
@@ -330,7 +356,7 @@
     [item setImage:image];
     [item setAction:@selector(setPrefView:)];
     [item setAutovalidates:NO];
-    return [item autorelease];
+    return item;
 }
 
 @end
