@@ -5,7 +5,6 @@
  It may be used under the terms of the GNU General Public License. */
 
 #import <Cocoa/Cocoa.h>
-#import "HBViewValidation.h"
 
 @class HBPresetsManager;
 @class HBPreset;
@@ -17,18 +16,23 @@
 
 @end
 
-@interface HBPresetsViewController : NSViewController <HBViewValidation>
+@interface HBPresetsViewController : NSViewController <NSUserInterfaceValidations>
 
 - (instancetype)initWithPresetManager:(HBPresetsManager *)presetManager;
 
 @property (nonatomic, readwrite, assign) id<HBPresetsViewControllerDelegate> delegate;
 
+- (IBAction)exportPreset:(id)sender;
+- (IBAction)importPreset:(id)sender;
+
 - (void)deselect;
 - (void)setSelection:(HBPreset *)preset;
 
 - (IBAction)insertFolder:(id)sender;
 
-@property (nonatomic, readonly) HBPreset *selectedPreset;
+@property (nonatomic, readonly, weak) HBPreset *selectedPreset;
 @property (nonatomic, readonly) NSUInteger indexOfSelectedItem;
 
+@property (nonatomic, readwrite, getter=isEnabled) BOOL enabled;
+
 @end
