@@ -5,19 +5,16 @@
  It may be used under the terms of the GNU General Public License. */
 
 #import <Cocoa/Cocoa.h>
-#include "hb.h"
 
+@class HBPreviewGenerator;
+@class HBPicture;
 @class HBController;
 
 @interface HBPreviewController : NSWindowController <NSWindowDelegate>
 
-@property (nonatomic) BOOL deinterlacePreview;
-@property (nonatomic, readonly) NSString *pictureSizeInfoString;
+@property (nonatomic, strong) HBPreviewGenerator *generator;
+@property (nonatomic, strong) HBPicture *picture;
 
-@property (nonatomic, assign) HBController *delegate;
-@property (nonatomic, assign) hb_handle_t *handle;
-@property (nonatomic, assign) hb_title_t *title;
-
-- (void) reload;
+@property (nonatomic, assign) HBController *documentController;
 
 @end
