@@ -6,12 +6,21 @@
 
 #import <Foundation/Foundation.h>
 
+NS_ASSUME_NONNULL_BEGIN
+
+@class HBJob;
+
 @interface HBUtilities : NSObject
 
 /**
- *  Returns the path of the current <user>/Library/Application Support/HandBrake folder.
+ *  Returns a formatted string that contains the application version.
  */
-+ (NSString *)appSupportPath;
++ (NSString *)handBrakeVersion;
+
+/**
+ *  Returns the url of the current <user>/Library/Application Support/HandBrake folder.
+ */
++ (nullable NSURL *)appSupportURL;
 
 /**
  *  Writes a message to standard error.
@@ -21,6 +30,13 @@
  */
 + (void)writeToActivityLog:(const char *)format, ...;
 
++ (NSString *)displayNameForURL:(NSURL *)URL;
++ (NSURL *)mediaURLFromURL:(NSURL *)URL;
+
++ (NSString *)automaticNameForJob:(HBJob *)job;
++ (NSString *)automaticExtForJob:(HBJob *)job;
++ (NSURL *)destURLForJob:(HBJob *)job;
+
 /**
  *  Generates a file name automatically based on the inputs,
  *  it can be configured with NSUserDefaults.
@@ -37,8 +53,14 @@
 + (NSString *)automaticNameForSource:(NSString *)sourceName
                                title:(NSUInteger)title
                             chapters:(NSRange)chaptersRange
-                             quality:(NSString *)quality
-                             bitrate:(NSString *)bitrate
+                             quality:(double)quality
+                             bitrate:(int)bitrate
                           videoCodec:(uint32_t)codec;
 
++ (NSString *)isoCodeForNativeLang:(NSString *)language;
++ (NSString *)iso6392CodeFor:(NSString *)language;
++ (NSString *)languageCodeForIso6392Code:(NSString *)language;
+
 @end
+
+NS_ASSUME_NONNULL_END
