@@ -78,27 +78,34 @@ namespace HandBrakeWPF.Commands
                     mainViewModel.AddToQueue();
                 }
 
-                // Scan a File (Ctrl+F)
-                if (gesture.Modifiers == ModifierKeys.Control && gesture.Key == Key.F)
+                // Scan a File (Alt+O)
+                if (gesture.Modifiers == ModifierKeys.Alt && gesture.Key == Key.O)
                 {
-                    mainViewModel.FileScan();
-                    MessageBox.Show("Please use Ctrl-O in future. Ctrl-F is being deprecated in favour of something more standard. :)");
+                    mainViewModel.SelectSourceWindow();
                 }
 
+                // Scan a File (Ctrl+O)
                 if (gesture.Modifiers == ModifierKeys.Control && gesture.Key == Key.O)
                 {
                     mainViewModel.FileScan();
                 }
 
-                // Scan a Folder (Ctrl+R)
-                if (gesture.Modifiers == ModifierKeys.Control && gesture.Key == Key.R)
+                // Scan a Folder (Ctrl+Shift+O)
+                if (gesture.Modifiers == (ModifierKeys.Control | ModifierKeys.Shift)  && gesture.Key == Key.O)
                 {
                     mainViewModel.FolderScan();
                 }
 
-                if (gesture.Modifiers == (ModifierKeys.Control | ModifierKeys.Shift) && gesture.Key == Key.D)
+                // Launch Help (F1)
+                if (gesture.Key == Key.F1)
                 {
-                    mainViewModel.ShowCliQuery();
+                    mainViewModel.LaunchHelp();
+                }
+
+                if (gesture.Modifiers == (ModifierKeys.Control | ModifierKeys.Shift) && gesture.Key == Key.G)
+                {
+                    GC.Collect();
+                    MessageBox.Show("DEBUG: Garbage Collection Completed");
                 }
             }
         }
