@@ -13,12 +13,17 @@ namespace HandBrakeWPF.Converters.Audio
     using System.Collections.Generic;
     using System.Globalization;
     using System.Linq;
+    using System.Windows;
     using System.Windows.Data;
 
-    using HandBrake.ApplicationServices.Model;
-    using HandBrake.ApplicationServices.Model.Encoding;
+    using HandBrake.ApplicationServices.Interop;
     using HandBrake.ApplicationServices.Utilities;
-    using HandBrake.Interop.Model.Encoding;
+
+    using HandBrakeWPF.Utilities;
+
+    using AudioEncoder = HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder;
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
+    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
 
     /// <summary>
     /// Audio Encoder Converter
@@ -51,27 +56,38 @@ namespace HandBrakeWPF.Converters.Audio
                 List<AudioEncoder> encoders = EnumHelper<AudioEncoder>.GetEnumList().ToList();
                 EncodeTask task = values[1] as EncodeTask;
 
+                if (!HandBrakeEncoderHelpers.AudioEncoders.Any(a => a.ShortName.Contains("fdk")))
+                {
+                    encoders.Remove(AudioEncoder.fdkaac);
+                    encoders.Remove(AudioEncoder.fdkheaac);
+                }
+
                 if (task != null && task.OutputFormat != OutputFormat.Mkv)
                 {
                     encoders.Remove(AudioEncoder.Vorbis);
                     encoders.Remove(AudioEncoder.ffflac);
                     encoders.Remove(AudioEncoder.ffflac24);
+                    encoders.Remove(AudioEncoder.FlacPassthru);
+                    encoders.Remove(AudioEncoder.Opus);
                 }
 
                 if (parameter != null && parameter.ToString() == "True")
                 {
                     encoders.Remove(AudioEncoder.DtsHDPassthrough);
                     encoders.Remove(AudioEncoder.DtsPassthrough);
+                    encoders.Remove(AudioEncoder.EAc3Passthrough);
                     encoders.Remove(AudioEncoder.AacPassthru);
                     encoders.Remove(AudioEncoder.Ac3Passthrough);
                     encoders.Remove(AudioEncoder.Mp3Passthru);
                     encoders.Remove(AudioEncoder.Passthrough);
+                    encoders.Remove(AudioEncoder.TrueHDPassthrough);
+                    encoders.Remove(AudioEncoder.FlacPassthru);
                 }
 
                 return EnumHelper<AudioEncoder>.GetEnumDisplayValuesSubset(encoders);
             }
 
-            if (values.Any())
+            if (values.Any() && values.First() != DependencyProperty.UnsetValue)
             {
                 return EnumHelper<AudioEncoder>.GetDisplay((AudioEncoder)values[0]);
             }
