@@ -15,10 +15,15 @@ namespace HandBrakeWPF.Converters.Video
     using System.Linq;
     using System.Windows.Data;
 
-    using HandBrake.ApplicationServices.Model;
-    using HandBrake.ApplicationServices.Model.Encoding;
+    using HandBrake.ApplicationServices.Interop;
     using HandBrake.ApplicationServices.Utilities;
-    using HandBrake.Interop.Model.Encoding;
+    using HandBrake.ApplicationServices.Interop.Model.Encoding;
+
+    using HandBrakeWPF.Utilities;
+
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
+    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
+    using SystemInfo = HandBrake.ApplicationServices.Utilities.SystemInfo;
 
     /// <summary>
     /// Video Encoder Converter
@@ -50,17 +55,38 @@ namespace HandBrakeWPF.Converters.Video
                 List<VideoEncoder> encoders = EnumHelper<VideoEncoder>.GetEnumList().ToList();
                 EncodeTask task = values[1] as EncodeTask;
 
+                if (HandBrakeEncoderHelpers.VideoEncoders.All(a => a.ShortName != EnumHelper<VideoEncoder>.GetShortName(VideoEncoder.X264_10)))
+                {
+                    encoders.Remove(VideoEncoder.X264_10);
+                }
+
+                if (HandBrakeEncoderHelpers.VideoEncoders.All(a => a.ShortName != EnumHelper<VideoEncoder>.GetShortName(VideoEncoder.X265_10)))
+                {
+                    encoders.Remove(VideoEncoder.X265_10);
+                }
+
+                if (HandBrakeEncoderHelpers.VideoEncoders.All(a => a.ShortName != EnumHelper<VideoEncoder>.GetShortName(VideoEncoder.X265_12)))
+                {
+                    encoders.Remove(VideoEncoder.X265_12);
+                }
+
                 if (task != null && task.OutputFormat != OutputFormat.Mkv)
                 {
                     encoders.Remove(VideoEncoder.Theora);
                     encoders.Remove(VideoEncoder.VP8);
+                    encoders.Remove(VideoEncoder.VP9);
                 }
 
-                if (!SystemInfo.IsQsvAvailable)
+                if (!SystemInfo.IsQsvAvailableH264)
                 {
                     encoders.Remove(VideoEncoder.QuickSync);
                 }
 
+                if (!SystemInfo.IsQsvAvailableH265)
+                {
+                    encoders.Remove(VideoEncoder.QuickSyncH265);
+                }
+
                 return EnumHelper<VideoEncoder>.GetEnumDisplayValuesSubset(encoders);
             }
 
