@@ -11,6 +11,7 @@ namespace HandBrakeWPF.Helpers
 {
     using System;
     using System.Collections.Generic;
+    using System.Diagnostics;
     using System.Globalization;
     using System.IO;
     using System.Linq;
@@ -19,10 +20,13 @@ namespace HandBrakeWPF.Helpers
     using System.Xml.Serialization;
 
     using HandBrake.ApplicationServices.Model;
-    using HandBrake.ApplicationServices.Services.Interfaces;
     using HandBrake.ApplicationServices.Utilities;
 
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Queue.Model;
+    using HandBrakeWPF.Utilities;
+
+    using IQueueProcessor = HandBrakeWPF.Services.Queue.Interfaces.IQueueProcessor;
 
     /// <summary>
     /// Queue Recovery Helper
@@ -41,32 +45,44 @@ namespace HandBrakeWPF.Helpers
         {
             try
             {
-                XmlSerializer Ser = new XmlSerializer(typeof(List<QueueTask>));
                 string tempPath = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData), @"HandBrake\");
                 List<string> queueFiles = new List<string>();
-                List<string> removeFiles = new List<string>();
-
                 DirectoryInfo info = new DirectoryInfo(tempPath);
                 IEnumerable<FileInfo> logFiles = info.GetFiles("*.xml").Where(f => f.Name.StartsWith("hb_queue_recovery"));
+
+                if (!logFiles.Any())
+                {
+                    return queueFiles;
+                }
+
+                List<string> removeFiles = new List<string>();
+                XmlSerializer Ser = new XmlSerializer(typeof(List<QueueTask>));
                 foreach (FileInfo file in logFiles)
                 {
-                    using (FileStream strm = new FileStream(file.FullName, FileMode.Open, FileAccess.Read))
+                    try
                     {
-                        List<QueueTask> list = Ser.Deserialize(strm) as List<QueueTask>;
-                        if (list != null && list.Count == 0)
+                        using (FileStream strm = new FileStream(file.FullName, FileMode.Open, FileAccess.Read))
                         {
-                            removeFiles.Add(file.FullName);
-                        }
-
-                        if (list != null && list.Count != 0)
-                        {
-                            List<QueueTask> tasks = list.Where(l => l.Status != QueueItemStatus.Completed).ToList();
-                            if (tasks.Count != 0)
+                            List<QueueTask> list = Ser.Deserialize(strm) as List<QueueTask>;
+                            if (list != null && list.Count == 0)
                             {
-                                queueFiles.Add(file.Name);
+                                removeFiles.Add(file.FullName);
+                            }
+
+                            if (list != null && list.Count != 0)
+                            {
+                                List<QueueTask> tasks = list.Where(l => l.Status != QueueItemStatus.Completed).ToList();
+                                if (tasks.Count != 0)
+                                {
+                                    queueFiles.Add(file.Name);
+                                }
                             }
                         }
                     }
+                    catch (Exception exc)
+                    {
+                        Debug.WriteLine(exc);
+                    }
                 }
 
                 // Cleanup old/unused queue files for now.
@@ -89,6 +105,7 @@ namespace HandBrakeWPF.Helpers
             }
             catch (Exception exc)
             {
+                Debug.WriteLine(exc);
                 return new List<string>(); // Keep quiet about the error.
             }
         }
@@ -102,29 +119,64 @@ namespace HandBrakeWPF.Helpers
         /// <param name="errorService">
         /// The error Service.
         /// </param>
-        public static void RecoverQueue(IQueueProcessor encodeQueue, IErrorService errorService)
+        /// <param name="silentRecovery">
+        /// The silent Recovery.
+        /// </param>
+        /// <returns>
+        /// The <see cref="bool"/>.
+        /// </returns>
+        public static bool RecoverQueue(IQueueProcessor encodeQueue, IErrorService errorService, bool silentRecovery)
         {
             string appDataPath = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData), @"HandBrake\");
             List<string> queueFiles = CheckQueueRecovery();
             MessageBoxResult result = MessageBoxResult.None;
-            if (queueFiles.Count == 1)
+            if (!silentRecovery)
             {
-                result = errorService.ShowMessageBox(
-                        "HandBrake has detected unfinished items on the queue from the last time the application was launched. Would you like to recover these?",
-                        "Queue Recovery Possible", MessageBoxButton.YesNo, MessageBoxImage.Question);
+                if (queueFiles.Count == 1)
+                {
+                    result =
+                        errorService.ShowMessageBox(
+                            "HandBrake has detected unfinished items on the queue from the last time the application was launched. Would you like to recover these?",
+                            "Queue Recovery Possible",
+                            MessageBoxButton.YesNo,
+                            MessageBoxImage.Question);
+                }
+                else if (queueFiles.Count > 1)
+                {
+                    result =
+                        errorService.ShowMessageBox(
+                            "HandBrake has detected multiple unfinished queue files. These will be from multiple instances of HandBrake running. Would you like to recover all unfinished jobs?",
+                            "Queue Recovery Possible",
+                            MessageBoxButton.YesNo,
+                            MessageBoxImage.Question);
+                }
             }
-            else if (queueFiles.Count > 1)
+            else
             {
-                result = MessageBox.Show(
-                        "HandBrake has detected multiple unfinished queue files. These will be from multiple instances of HandBrake running. Would you like to recover all unfinished jobs?",
-                        "Queue Recovery Possible", MessageBoxButton.YesNo, MessageBoxImage.Question);
+                result = MessageBoxResult.Yes;
             }
 
             if (result == MessageBoxResult.Yes)
             {
+                bool isRecovered = false;
                 foreach (string file in queueFiles)
                 {
-                    encodeQueue.RestoreQueue(appDataPath + file); // Start Recovery
+                    // Skip over the file if it belongs to another HandBrake instance.
+                    Match m = Regex.Match(file, @"([0-9]+).xml");
+                    if (m.Success)
+                    {
+                        int processId = int.Parse(m.Groups[1].ToString());
+                        if (processId != GeneralUtilities.ProcessId && GeneralUtilities.IsPidACurrentHandBrakeInstance(processId))
+                        {
+                            continue;
+                        }
+                    }
+
+                    // Recover the Queue
+                    encodeQueue.RestoreQueue(appDataPath + file);
+                    isRecovered = true;
+
+                    // Cleanup
                     if (!file.Contains(GeneralUtilities.ProcessId.ToString(CultureInfo.InvariantCulture)))
                     {
                         try
@@ -132,13 +184,15 @@ namespace HandBrakeWPF.Helpers
                             // Once we load it in, remove it as we no longer need it.
                             File.Delete(Path.Combine(appDataPath, file));
                         }
-                        catch (Exception exc)
+                        catch (Exception)
                         {
                             // Keep quite, nothing much we can do if there are problems.
                             // We will continue processing files.
                         }
                     }
                 }
+
+                return isRecovered;
             }
             else
             {
@@ -161,6 +215,8 @@ namespace HandBrakeWPF.Helpers
                         File.Delete(Path.Combine(appDataPath, file));
                     }
                 }
+
+                return false;
             }
         }
     }
