@@ -22,8 +22,8 @@ namespace HandBrakeWPF.Model
         [Display(Name = "Output Files")]
         OutputFiles,
 
-        [Display(Name = "Audio and Subtitles")]
-        AudioAndSubtitles,
+        [Display(Name = "Video")]
+        Video,
 
         [Display(Name = "Advanced")]
         Advanced,
