@@ -10,15 +10,22 @@
 namespace HandBrakeWPF.Services
 {
     using System;
+    using System.Diagnostics;
     using System.IO;
     using System.Net;
+    using System.Reflection;
+    using System.Security.Cryptography;
+    using System.Text;
     using System.Threading;
 
     using HandBrake.ApplicationServices.Utilities;
+    using HandBrake.ApplicationServices.Interop;
 
     using HandBrakeWPF.Model;
     using HandBrakeWPF.Services.Interfaces;
 
+    using AppcastReader = HandBrakeWPF.Utilities.AppcastReader;
+
     /// <summary>
     /// The Update Service
     /// </summary>
@@ -61,8 +68,10 @@ namespace HandBrakeWPF.Services
             // Make sure it's running on the calling thread
             if (this.userSettingService.GetUserSetting<bool>(UserSettingConstants.UpdateStatus))
             {
-                if (DateTime.Now.Subtract(this.userSettingService.GetUserSetting<DateTime>(UserSettingConstants.LastUpdateCheckDate)).TotalDays
-                    > this.userSettingService.GetUserSetting<int>(UserSettingConstants.DaysBetweenUpdateCheck))
+                DateTime lastUpdateCheck = this.userSettingService.GetUserSetting<DateTime>(UserSettingConstants.LastUpdateCheckDate);
+                int checkFrequency = this.userSettingService.GetUserSetting<int>(UserSettingConstants.DaysBetweenUpdateCheck) == 0 ? 7 : 30;
+
+                if (DateTime.Now.Subtract(lastUpdateCheck).TotalDays > checkFrequency)
                 {
                     this.userSettingService.SetUserSetting(UserSettingConstants.LastUpdateCheckDate, DateTime.Now);
 
@@ -84,6 +93,7 @@ namespace HandBrakeWPF.Services
                 {
                     try
                     {
+                        // Figure out which appcast we want to read.
                         string url =
                             VersionHelper.Is64Bit() || Environment.Is64BitOperatingSystem
                                 ? Constants.Appcast64
@@ -96,35 +106,35 @@ namespace HandBrakeWPF.Services
                                 ? Constants.AppcastUnstable64
                                 : Constants.AppcastUnstable32;
                         }
-                        
-                        var currentBuild =
-                            this.userSettingService.GetUserSetting<int>(UserSettingConstants.HandBrakeBuild);
-                        var skipBuild = this.userSettingService.GetUserSetting<int>(
-                            UserSettingConstants.Skipversion);
 
-                        // Initialize variables
-                        WebRequest request = WebRequest.Create(url);
+                        var currentBuild = HandBrakeUtils.Build;
+
+                        // Fetch the Appcast from our server.
+                        HttpWebRequest request = (HttpWebRequest) WebRequest.Create(url);
+                        request.AllowAutoRedirect = false; // We will never do this.
                         WebResponse response = request.GetResponse();
-                        var reader = new AppcastReader();
 
-                        // Get the data, convert it to a string, and parse it into the AppcastReader
+                        // Parse the data with the AppcastReader
+                        var reader = new AppcastReader();
                         reader.GetUpdateInfo(new StreamReader(response.GetResponseStream()).ReadToEnd());
 
                         // Further parse the information
                         string build = reader.Build;
-
                         int latest = int.Parse(build);
                         int current = currentBuild;
-                        int skip = skipBuild;
 
-                        // If the user wanted to skip this version, don't report the update
-                        if (latest == skip)
+                        // Security Check
+                        // Verify the download URL is for handbrake.fr and served over https.
+                        // This prevents a compromised appcast download tricking the GUI into downloading a file, or accessing another website or local network resource.
+                        Uri uriResult;
+                        bool result = Uri.TryCreate(reader.DownloadFile, UriKind.Absolute, out uriResult) && uriResult.Scheme == Uri.UriSchemeHttps;
+                        if (!result || (uriResult.Host != "handbrake.fr" && uriResult.Host != "download.handbrake.fr"))
                         {
-                            var info = new UpdateCheckInformation { NewVersionAvailable = false };
-                            callback(info);
+                            callback(new UpdateCheckInformation { NewVersionAvailable = false, Error = new Exception("The HandBrake update service is currently unavailable.") });
                             return;
                         }
 
+                        // Validate the URL from the appcast is ours.
                         var info2 = new UpdateCheckInformation
                             {
                                 NewVersionAvailable = latest > current,
@@ -132,6 +142,7 @@ namespace HandBrakeWPF.Services
                                 DownloadFile = reader.DownloadFile,
                                 Build = reader.Build,
                                 Version = reader.Version,
+                                Signature = reader.Hash
                             };
 
                         callback(info2);
@@ -149,13 +160,16 @@ namespace HandBrakeWPF.Services
         /// <param name="url">
         /// The url.
         /// </param>
+        /// <param name="expectedSignature">
+        /// The expected DSA SHA265 Signature
+        /// </param>
         /// <param name="completed">
         /// The complete.
         /// </param>
         /// <param name="progress">
         /// The progress.
         /// </param>
-        public void DownloadFile(string url, Action<DownloadStatus> completed, Action<DownloadStatus> progress)
+        public void DownloadFile(string url, string expectedSignature, Action<DownloadStatus> completed, Action<DownloadStatus> progress)
         {
             ThreadPool.QueueUserWorkItem(
                delegate
@@ -179,11 +193,9 @@ namespace HandBrakeWPF.Services
                        int bytesSize;
                        byte[] downBuffer = new byte[2048];
 
-                       long flength = 0;
                        while ((bytesSize = responceStream.Read(downBuffer, 0, downBuffer.Length)) > 0)
                        {
                            localStream.Write(downBuffer, 0, bytesSize);
-                           flength = localStream.Length;
                            progress(new DownloadStatus { BytesRead = localStream.Length, TotalBytes = fileSize});
                        }
 
@@ -191,21 +203,72 @@ namespace HandBrakeWPF.Services
                        localStream.Close();
 
                        completed(
-                           flength != fileSize
-                               ? new DownloadStatus
+                           this.VerifyDownload(expectedSignature, tempPath)
+                               ? new DownloadStatus { WasSuccessful = true, Message = "Download Complete." } :
+                                 new DownloadStatus
                                    {
                                        WasSuccessful = false,
-                                       Message = "Partial Download. File is Incomplete. Please Retry the download."
-                                   }
-                               : new DownloadStatus { WasSuccessful = true, Message = "Download Complete." });
+                                       Message = "Download Failed.  Checksum Failed. Please visit the website to download this update."
+                                   });
                    }
                    catch (Exception exc)
                    {
-                       progress(new DownloadStatus { WasSuccessful = false, Exception = exc, Message = "Download Failed." });
+                       progress(new DownloadStatus { WasSuccessful = false, Exception = exc, Message = "Download Failed. Please visit the website to download this update." });
                    }
                });
         }
 
+        /// <summary>
+        /// Verify the HandBrake download is Valid.
+        /// </summary>
+        /// <param name="signature">The DSA SHA256 Signature from the appcast</param>
+        /// <param name="updateFile">Path to the downloaded update file</param>
+        /// <returns>True if the file is valid, false otherwise.</returns>
+        public bool VerifyDownload(string signature, string updateFile)
+        {
+            // Sanity Checks
+            if (!File.Exists(updateFile))
+            {
+                return false;
+            }
+
+            if (string.IsNullOrEmpty(signature))
+            {
+                return false;
+            }
+
+            // Fetch our Public Key
+            string publicKey;
+            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("HandBrakeWPF.public.key"))
+            {
+                if (stream == null)
+                {
+                    return false;
+                }
+
+                using (StreamReader reader = new StreamReader(stream))
+                {
+                    publicKey = reader.ReadToEnd();
+                }
+            }
+            
+            // Verify the file against the Signature. 
+            try
+            {
+                byte[] file = File.ReadAllBytes(updateFile);
+                using (RSACryptoServiceProvider verifyProfider = new RSACryptoServiceProvider())
+                {
+                    verifyProfider.FromXmlString(publicKey);
+                    return verifyProfider.VerifyData(file, "SHA256", Convert.FromBase64String(signature));
+                }
+            }
+            catch (Exception e)
+            {
+                Debug.WriteLine(e);
+                return false;
+            }
+        }
+
         #endregion
     }
 }
\ No newline at end of file
