@@ -16,46 +16,32 @@ namespace HandBrakeWPF.ViewModels
 
     using Caliburn.Micro;
 
-    using HandBrake.ApplicationServices.Model;
-    using HandBrake.ApplicationServices.Model.Audio;
-    using HandBrake.ApplicationServices.Model.Encoding;
-    using HandBrake.ApplicationServices.Parsing;
+    using HandBrake.ApplicationServices.Interop;
+    using HandBrake.ApplicationServices.Interop.Model.Encoding;
     using HandBrake.ApplicationServices.Utilities;
-    using HandBrake.Interop.Model.Encoding;
 
+    using HandBrakeWPF.Model.Audio;
+    using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Presets.Model;
+    using HandBrakeWPF.Services.Scan.Model;
+    using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
 
+    using AudioEncoder = HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder;
+    using AudioTrack = HandBrakeWPF.Services.Encode.Model.Models.AudioTrack;
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
+    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
+
     /// <summary>
     /// The Audio View Model
     /// </summary>
     public class AudioViewModel : ViewModelBase, IAudioViewModel
     {
-        /// <summary>
-        /// Backing field for the source tracks list.
-        /// </summary>
+        private readonly IWindowManager windowManager;
         private IEnumerable<Audio> sourceTracks;
-
-        /// <summary>
-        /// The current preset.
-        /// </summary>
         private Preset currentPreset;
 
-        /// <summary>
-        /// The show audio defaults panel.
-        /// </summary>
-        private bool showAudioDefaultsPanel;
-
-        /// <summary>
-        /// The available languages.
-        /// </summary>
-        private BindingList<string> availableLanguages;
-
-        /// <summary>
-        /// The audio behaviours.
-        /// </summary>
-        private AudioBehaviours audioBehaviours;
-
         #region Constructors and Destructors
 
         /// <summary>
@@ -69,17 +55,18 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         public AudioViewModel(IWindowManager windowManager, IUserSettingService userSettingService)
         {
+            this.windowManager = windowManager;
             this.Task = new EncodeTask();
-            this.SampleRates = new ObservableCollection<string> { "Auto", "48", "44.1", "32", "24", "22.05", "16", "12", "11.025", "8" };
-            this.AudioEncoders = EnumHelper<AudioEncoder>.GetEnumList();
-            this.AudioMixdowns = EnumHelper<Mixdown>.GetEnumList();
-            this.SourceTracks = new List<Audio>();
+            this.AudioDefaultsViewModel = new AudioDefaultsViewModel(this.Task);
 
-            this.AudioBehaviours = new AudioBehaviours();
-            this.SelectedAvailableToMove = new BindingList<string>();
-            this.SelectedLangaugesToMove = new BindingList<string>();
-            this.AvailableLanguages = new BindingList<string>();
-            this.SetupLanguages(null);
+            this.SampleRates = new ObservableCollection<string> { "Auto" };
+            foreach (var item in HandBrakeEncoderHelpers.AudioSampleRates)
+            {
+                this.SampleRates.Add(item.Name);
+            }
+
+            this.AudioEncoders = EnumHelper<AudioEncoder>.GetEnumList();
+            this.SourceTracks = new List<Audio>();
         }
 
         #endregion
@@ -87,55 +74,19 @@ namespace HandBrakeWPF.ViewModels
         #region Properties
 
         /// <summary>
-        /// Gets or sets the audio behaviours.
+        /// Gets or sets the audio defaults view model.
         /// </summary>
-        public AudioBehaviours AudioBehaviours
-        {
-            get
-            {
-                return this.audioBehaviours;
-            }
-            set
-            {
-                if (Equals(value, this.audioBehaviours))
-                {
-                    return;
-                }
-                this.audioBehaviours = value;
-                this.NotifyOfPropertyChange(() => this.AudioBehaviours);
-            }
-        }
-
-        /// <summary>
-        /// Gets the audio behaviour modes.
-        /// </summary>
-        public BindingList<AudioBehaviourModes> AudioBehaviourModeList
-        {
-            get
-            {
-                return new BindingList<AudioBehaviourModes>(EnumHelper<AudioBehaviourModes>.GetEnumList().ToList());
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets AudioBitrates.
-        /// </summary>
-        public IEnumerable<int> AudioBitrates { get; set; }
+        public IAudioDefaultsViewModel AudioDefaultsViewModel { get; set; }
 
         /// <summary>
         /// Gets or sets AudioEncoders.
         /// </summary>
         public IEnumerable<AudioEncoder> AudioEncoders { get; set; }
 
-        /// <summary>
-        /// Gets or sets AudioMixdowns.
-        /// </summary>
-        public IEnumerable<Mixdown> AudioMixdowns { get; set; }
-
         /// <summary>
         /// Gets or sets SampleRates.
         /// </summary>
-        public IEnumerable<string> SampleRates { get; set; }
+        public IList<string> SampleRates { get; set; }
 
         /// <summary>
         /// Gets or sets SourceTracks.
@@ -158,28 +109,6 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public EncodeTask Task { get; set; }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether show audio defaults panel.
-        /// </summary>
-        public bool ShowAudioDefaultsPanel
-        {
-            get
-            {
-                return this.showAudioDefaultsPanel;
-            }
-            set
-            {
-                if (value.Equals(this.showAudioDefaultsPanel))
-                {
-                    return;
-                }
-                this.showAudioDefaultsPanel = value;
-                this.NotifyOfPropertyChange(() => this.ShowAudioDefaultsPanel);
-                this.NotifyOfPropertyChange(() => this.PanelTitle);
-                this.NotifyOfPropertyChange(() => this.SwitchDisplayTitle);
-            }
-        }
-
         /// <summary>
         /// Gets the panel title.
         /// </summary>
@@ -187,7 +116,7 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return this.ShowAudioDefaultsPanel ? "Audio Defaults" : "Audio Tracks";
+                return Resources.AudioViewModel_AudioTracks;
             }
         }
 
@@ -198,37 +127,21 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return this.ShowAudioDefaultsPanel ? "Switch to Tracks" : "Switch to Defaults";
+                return Resources.AudioViewModel_ConfigureDefaults;
             }
         }
 
         /// <summary>
-        /// Gets or sets AvailableLanguages.
+        /// Gets the default audio behaviours. 
         /// </summary>
-        public BindingList<string> AvailableLanguages
+        public AudioBehaviours AudioBehaviours
         {
             get
             {
-                return this.availableLanguages;
-            }
-
-            set
-            {
-                this.availableLanguages = value;
-                this.NotifyOfPropertyChange("AvailableLanguages");
+                return this.AudioDefaultsViewModel.AudioBehaviours;
             }
         }
 
-        /// <summary>
-        /// Gets or sets SelectedLangauges.
-        /// </summary>
-        public BindingList<string> SelectedAvailableToMove { get; set; }
-
-        /// <summary>
-        /// Gets or sets SelectedLangauges.
-        /// </summary>
-        public BindingList<string> SelectedLangaugesToMove { get; set; }
-
         #endregion
 
         #region Public Methods
@@ -239,7 +152,7 @@ namespace HandBrakeWPF.ViewModels
         public void Add()
         {
             // Add the first track if available.
-            this.Add(null);
+            this.Add(null, false);
         }
 
         /// <summary>
@@ -269,6 +182,14 @@ namespace HandBrakeWPF.ViewModels
             this.Task.AudioTracks.Clear();
         }
 
+        /// <summary>
+        /// Reload the audio tracks based on the defaults.
+        /// </summary>
+        public void ReloadDefaults()
+        {
+            this.SetupTracks();
+        }
+
         /// <summary>
         /// Trigger a Notify Property Changed on the Task to force various UI elements to update.
         /// </summary>
@@ -276,21 +197,15 @@ namespace HandBrakeWPF.ViewModels
         {
             this.NotifyOfPropertyChange(() => this.Task);
 
-            if (Task.OutputFormat == OutputFormat.Mp4)
+            if (this.Task.OutputFormat == OutputFormat.Mp4)
             {
                 foreach (AudioTrack track in this.Task.AudioTracks.Where(track => track.Encoder == AudioEncoder.ffflac || track.Encoder == AudioEncoder.Vorbis))
                 {
                     track.Encoder = AudioEncoder.ffaac;
                 }
             }
-        }
 
-        /// <summary>
-        /// Open the options screen to the Audio and Subtitles tab.
-        /// </summary>
-        public void SetDefaultBehaviour()
-        {
-            this.ShowAudioDefaultsPanel = true;
+            this.AudioDefaultsViewModel.RefreshTask();
         }
 
         /// <summary>
@@ -298,57 +213,15 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void ShowAudioDefaults()
         {
-            this.ShowAudioDefaultsPanel = !this.ShowAudioDefaultsPanel;
-        }
-
-        /// <summary>
-        /// Audio List Move Left
-        /// </summary>
-        public void LanguageMoveRight()
-        {
-            if (this.SelectedAvailableToMove.Count > 0)
+            IPopupWindowViewModel popup = new PopupWindowViewModel(this.AudioDefaultsViewModel, ResourcesUI.Preset_AudioDefaults_Title, ResourcesUI.AudioView_AudioDefaultsDescription);
+            if (this.windowManager.ShowDialog(popup) == true)
             {
-                List<string> copiedList = SelectedAvailableToMove.ToList();
-                foreach (string item in copiedList)
-                {
-                    this.AvailableLanguages.Remove(item);
-                    this.AudioBehaviours.SelectedLangauges.Add(item);
-                }
-
-                this.AvailableLanguages = new BindingList<string>(this.AvailableLanguages.OrderBy(o => o).ToList());
+                // Nothing to do yet, it's by reference. 
             }
-        }
-
-        /// <summary>
-        /// Audio List Move Right
-        /// </summary>
-        public void LanguageMoveLeft()
-        {
-            if (this.SelectedLangaugesToMove.Count > 0)
+            else
             {
-                List<string> copiedList = SelectedLangaugesToMove.ToList();
-                foreach (string item in copiedList)
-                {
-                    this.AudioBehaviours.SelectedLangauges.Remove(item);
-                    this.AvailableLanguages.Add(item);
-                }
+                // Handle other case(s)
             }
-
-            this.AvailableLanguages = new BindingList<string>(this.AvailableLanguages.OrderBy(o => o).ToList());
-        }
-
-        /// <summary>
-        /// Audio List Clear all selected languages
-        /// </summary>
-        public void LanguageClearAll()
-        {
-            foreach (string item in this.AudioBehaviours.SelectedLangauges)
-            {
-                this.AvailableLanguages.Add(item);
-            }
-            this.AvailableLanguages = new BindingList<string>(this.AvailableLanguages.OrderBy(o => o).ToList());
-
-            this.AudioBehaviours.SelectedLangauges.Clear();
         }
 
         #endregion
@@ -370,12 +243,10 @@ namespace HandBrakeWPF.ViewModels
             this.currentPreset = preset;
 
             // Audio Behaviours
-            this.SetupLanguages(preset);
+            this.AudioDefaultsViewModel.Setup(preset, task);
 
             if (preset != null && preset.Task != null)
             {
-                this.Task.AllowedPassthruOptions = new AllowedPassthru(preset.Task.AllowedPassthruOptions);
-
                 this.SetupTracks();
             }
 
@@ -391,13 +262,16 @@ namespace HandBrakeWPF.ViewModels
         public void UpdateTask(EncodeTask task)
         {
             this.Task = task;
-            this.NotifyOfPropertyChange(() => Task.AudioTracks);
+            this.NotifyOfPropertyChange(() => this.Task.AudioTracks);
             this.NotifyOfPropertyChange(() => this.Task);
         }
 
         /// <summary>
         /// Set the Source Title
         /// </summary>
+        /// <param name="source">
+        /// The source.
+        /// </param>
         /// <param name="title">
         /// The title.
         /// </param>
@@ -407,7 +281,7 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="task">
         /// The task.
         /// </param>
-        public void SetSource(Title title, Preset preset, EncodeTask task)
+        public void SetSource(Source source, Title title, Preset preset, EncodeTask task)
         {
             this.SourceTracks = title.AudioTracks;
 
@@ -441,14 +315,39 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="sourceTrack">
         /// The source track.
         /// </param>
-        private void Add(Audio sourceTrack)
+        /// <param name="useBehaviourTemplateMode">
+        /// The use Behaviour Template Mode.
+        /// </param>
+        private void Add(Audio sourceTrack, bool useBehaviourTemplateMode)
         {
             if (this.SourceTracks != null)
             {
                 Audio track = sourceTrack ?? this.GetPreferredAudioTrack();
                 if (track != null)
                 {
-                    this.Task.AudioTracks.Add(new AudioTrack { ScannedTrack = track });
+                    if (!useBehaviourTemplateMode)
+                    {
+                        this.Task.AudioTracks.Add(new AudioTrack { ScannedTrack = track });
+                        return;
+                    }
+
+                    switch (this.AudioBehaviours.SelectedTrackDefaultBehaviour)
+                    {
+                        case AudioTrackDefaultsMode.None:
+                            this.Task.AudioTracks.Add(new AudioTrack { ScannedTrack = track });
+                            break;
+                        case AudioTrackDefaultsMode.FirstTrack:
+                            AudioBehaviourTrack template = this.AudioBehaviours.BehaviourTracks.FirstOrDefault();
+                            this.Task.AudioTracks.Add(template != null ? new AudioTrack(template) { ScannedTrack = track } : new AudioTrack { ScannedTrack = track });
+                            break;
+                        case AudioTrackDefaultsMode.AllTracks:
+                            foreach (AudioBehaviourTrack tmpl in this.AudioBehaviours.BehaviourTracks)
+                            {
+                                this.Task.AudioTracks.Add(tmpl != null ? new AudioTrack(tmpl) { ScannedTrack = track } : new AudioTrack { ScannedTrack = track });
+                            }
+
+                            break;
+                    }
                 }
             }
         }
@@ -466,7 +365,7 @@ namespace HandBrakeWPF.ViewModels
                 if (!found)
                 {
                     // If it doesn't, add it.
-                    this.Add(sourceTrack);
+                    this.Add(sourceTrack, true);
                 }
             }
         }
@@ -494,7 +393,7 @@ namespace HandBrakeWPF.ViewModels
             }
 
             // Step 3, Setup the tracks from the preset
-            foreach (AudioTrack track in this.currentPreset.Task.AudioTracks)
+            foreach (AudioBehaviourTrack track in this.AudioBehaviours.BehaviourTracks)
             {
                 this.Task.AudioTracks.Add(new AudioTrack(track) { ScannedTrack = this.GetPreferredAudioTrack() });
             }
@@ -502,6 +401,9 @@ namespace HandBrakeWPF.ViewModels
             // Step 4, Handle the default selection behaviour.
             switch (this.AudioBehaviours.SelectedBehaviour)
             {
+                case AudioBehaviourModes.None:
+                    this.Task.AudioTracks.Clear();
+                    break;
                 case AudioBehaviourModes.FirstMatch: // Adding all remaining audio tracks
                     this.AddFirstForSelectedLanguages();
                     break;
@@ -535,7 +437,7 @@ namespace HandBrakeWPF.ViewModels
                     }
 
                     // If it doesn't, add it.
-                    this.Add(sourceTrack);
+                    this.Add(sourceTrack, true);
                 }
             }
         }
@@ -553,7 +455,7 @@ namespace HandBrakeWPF.ViewModels
                 if (!found)
                 {
                     // If it doesn't, add it.
-                    this.Add(sourceTrack);
+                    this.Add(sourceTrack, true);
                 }
             }
         }
@@ -591,10 +493,12 @@ namespace HandBrakeWPF.ViewModels
         {
             List<Audio> trackList = new List<Audio>();
 
-            List<string> isoCodes = this.AudioBehaviours.SelectedLangauges.Contains(Constants.Any)
-                                            ? LanguageUtilities.GetIsoCodes()
-                                            : LanguageUtilities.GetLanguageCodes(
-                                                this.AudioBehaviours.SelectedLangauges.ToArray());
+            List<string> isoCodes = LanguageUtilities.GetLanguageCodes(this.AudioBehaviours.SelectedLangauges.ToArray());
+
+            if (isoCodes.Contains(Constants.Undefined))
+            {
+                isoCodes = LanguageUtilities.GetIsoCodes();
+            }
 
             foreach (string code in isoCodes)
             {
@@ -604,42 +508,6 @@ namespace HandBrakeWPF.ViewModels
             return trackList;
         }
 
-        /// <summary>
-        /// The setup languages.
-        /// </summary>
-        /// <param name="preset">
-        /// The preset.
-        /// </param>
-        private void SetupLanguages(Preset preset)
-        {
-            // Step 1, Set the behaviour mode
-            this.AudioBehaviours.SelectedBehaviour = AudioBehaviourModes.None;
-            this.AudioBehaviours.SelectedLangauges.Clear();
-
-            // Step 2, Get all the languages
-            IDictionary<string, string> langList = LanguageUtilities.MapLanguages();
-            langList = (from entry in langList orderby entry.Key ascending select entry).ToDictionary(pair => pair.Key, pair => pair.Value);
-
-            // Step 3, Setup Available Languages
-            this.AvailableLanguages.Clear();
-            foreach (string item in langList.Keys)
-            {
-                this.AvailableLanguages.Add(item);
-            }
-
-            // Step 4, Set the Selected Languages          
-            if (preset != null && preset.AudioTrackBehaviours != null)
-            {
-                this.AudioBehaviours.SelectedBehaviour = preset.AudioTrackBehaviours.SelectedBehaviour;
-
-                foreach (string selectedItem in preset.AudioTrackBehaviours.SelectedLangauges)
-                {
-                    this.AvailableLanguages.Remove(selectedItem);
-                    this.AudioBehaviours.SelectedLangauges.Add(selectedItem);
-                }
-            }
-        }
-
         #endregion
     }
 }
\ No newline at end of file
