@@ -9,7 +9,11 @@
 
 namespace HandBrakeWPF.ViewModels.Interfaces
 {
-    using HandBrake.ApplicationServices.Model;
+    using HandBrakeWPF.Model.Audio;
+    using HandBrakeWPF.Model.Subtitles;
+    using HandBrakeWPF.Services.Scan.Model;
+
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
 
     /// <summary>
     /// The Add Preset View Model
@@ -22,6 +26,15 @@ namespace HandBrakeWPF.ViewModels.Interfaces
         /// <param name="task">
         /// The Encode Task.
         /// </param>
-        void Setup(EncodeTask task);
+        /// <param name="title">
+        /// The title.
+        /// </param>
+        /// <param name="audioBehaviours">
+        /// The audio Behaviours.
+        /// </param>
+        /// <param name="subtitleBehaviours">
+        /// The subtitle Behaviours.
+        /// </param>
+        void Setup(EncodeTask task, Title title, AudioBehaviours audioBehaviours, SubtitleBehaviours subtitleBehaviours);
     }
 }
