@@ -9,7 +9,11 @@
 
 namespace HandBrakeWPF.ViewModels.Interfaces
 {
-    using HandBrake.ApplicationServices.Model;
+    using System.Windows;
+
+    using HandBrakeWPF.Services.Presets.Model;
+
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
 
     /// <summary>
     /// The Main Window View Model
@@ -21,6 +25,14 @@ namespace HandBrakeWPF.ViewModels.Interfaces
         /// </summary>
         Preset SelectedPreset { set; }
 
+        /// <summary>
+        /// The preset select.
+        /// </summary>
+        /// <param name="tag">
+        /// The tag.
+        /// </param>
+        void PresetSelect(object tag);
+
         /// <summary>
         /// Shutdown the Application
         /// </summary>
@@ -44,6 +56,16 @@ namespace HandBrakeWPF.ViewModels.Interfaces
         /// </returns>
         bool AddToQueue();
 
+        /// <summary>
+        /// The launch help.
+        /// </summary>
+        void LaunchHelp();
+
+        /// <summary>
+        /// The select source window.
+        /// </summary>
+        void SelectSourceWindow();
+
         /// <summary>
         /// File Scan
         /// </summary>
@@ -89,8 +111,11 @@ namespace HandBrakeWPF.ViewModels.Interfaces
         void Shutdown();
 
         /// <summary>
-        /// The show cli query.
+        /// The files dropped on window.
         /// </summary>
-        void ShowCliQuery();
+        /// <param name="e">
+        /// The e.
+        /// </param>
+        void FilesDroppedOnWindow(DragEventArgs e);
     }
 }
\ No newline at end of file
