@@ -9,7 +9,9 @@
 
 namespace HandBrakeWPF.ViewModels.Interfaces
 {
-    using HandBrake.ApplicationServices.Model;
+    using HandBrakeWPF.Services.Scan.Model;
+
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
 
     /// <summary>
     /// The Static Preview View Model Interface
@@ -22,7 +24,10 @@ namespace HandBrakeWPF.ViewModels.Interfaces
         /// <param name="task">
         /// The task.
         /// </param>
-        void UpdatePreviewFrame(EncodeTask task);
+        /// <param name="scannedSource">
+        /// The scanned Source.
+        /// </param>
+        void UpdatePreviewFrame(EncodeTask task, Source scannedSource);
 
         /// <summary>
         /// Gets or sets a value indicating whether is open.
