@@ -23,11 +23,16 @@ namespace HandBrakeWPF.ViewModels
     using HandBrake.ApplicationServices.Utilities;
 
     using HandBrakeWPF.Model;
+    using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     using Ookii.Dialogs.Wpf;
 
+    using Execute = Caliburn.Micro.Execute;
+    using SystemInfo = HandBrake.ApplicationServices.Utilities.SystemInfo;
+
     /// <summary>
     /// The Options View Model
     /// </summary>
@@ -35,290 +40,59 @@ namespace HandBrakeWPF.ViewModels
     {
         #region Constants and Fields
 
-        /// <summary>
-        /// Backing field for the user setting service.
-        /// </summary>
         private readonly IUserSettingService userSettingService;
-
-        /// <summary>
-        /// The Shell View Model
-        /// </summary>
-        private readonly IShellViewModel shellViewModel;
-
-        /// <summary>
-        /// Backing field for the update service.
-        /// </summary>
         private readonly IUpdateService updateService;
+        private readonly IErrorService errorService;
 
-        /// <summary>
-        /// The arguments.
-        /// </summary>
         private string arguments;
-
-        /// <summary>
-        /// The auto name default path.
-        /// </summary>
         private string autoNameDefaultPath;
-
-        /// <summary>
-        /// The automatically name files.
-        /// </summary>
         private bool automaticallyNameFiles;
-
-        /// <summary>
-        /// The autoname format.
-        /// </summary>
         private string autonameFormat;
-
-        /// <summary>
-        /// The change to title case.
-        /// </summary>
         private bool changeToTitleCase;
-
-        /// <summary>
-        /// The check for updates.
-        /// </summary>
         private bool checkForUpdates;
-
-        /// <summary>
-        /// The check for updates frequencies.
-        /// </summary>
         private BindingList<string> checkForUpdatesFrequencies = new BindingList<string>();
-
-        /// <summary>
-        /// The check for updates frequency.
-        /// </summary>
         private int checkForUpdatesFrequency;
-
-        /// <summary>
-        /// The clear old olgs.
-        /// </summary>
         private bool clearOldOlgs;
-
-        /// <summary>
-        /// The constant quality granularity.
-        /// </summary>
         private BindingList<string> constantQualityGranularity = new BindingList<string>();
-
-        /// <summary>
-        /// The copy log to encode directory.
-        /// </summary>
         private bool copyLogToEncodeDirectory;
-
-        /// <summary>
-        /// The copy log to sepcficed location.
-        /// </summary>
         private bool copyLogToSepcficedLocation;
-
-        /// <summary>
-        /// The disable libdvd nav.
-        /// </summary>
         private bool disableLibdvdNav;
-
-        /// <summary>
-        /// The disable p reset update check notification.
-        /// </summary>
-        private bool disablePresetUpdateCheckNotification;
-
-        /// <summary>
-        /// The growl after encode.
-        /// </summary>
-        private bool growlAfterEncode;
-
-        /// <summary>
-        /// The growl after queue.
-        /// </summary>
-        private bool growlAfterQueue;
-
-        /// <summary>
-        /// The log directory.
-        /// </summary>
         private string logDirectory;
-
-        /// <summary>
-        /// The log verbosity options.
-        /// </summary>
         private BindingList<int> logVerbosityOptions = new BindingList<int>();
-
-        /// <summary>
-        /// The min length.
-        /// </summary>
         private long minLength;
-
-        /// <summary>
-        /// The minimise to tray.
-        /// </summary>
         private bool minimiseToTray;
-
-        /// <summary>
-        /// The mp 4 extension options.
-        /// </summary>
         private BindingList<string> mp4ExtensionOptions = new BindingList<string>();
-
-        /// <summary>
-        /// The prevent sleep.
-        /// </summary>
         private bool preventSleep;
-
-        /// <summary>
-        /// The preview pictures to scan.
-        /// </summary>
         private BindingList<int> previewPicturesToScan = new BindingList<int>();
-
-        /// <summary>
-        /// The priority level options.
-        /// </summary>
         private BindingList<string> priorityLevelOptions = new BindingList<string>();
-
-        /// <summary>
-        /// The remove underscores.
-        /// </summary>
         private bool removeUnderscores;
-
-        /// <summary>
-        /// The selected granulairty.
-        /// </summary>
         private string selectedGranulairty;
-
-        /// <summary>
-        /// The selected mp 4 extension.
-        /// </summary>
         private int selectedMp4Extension;
-
-        /// <summary>
-        /// The selected preview count.
-        /// </summary>
         private int selectedPreviewCount;
-
-        /// <summary>
-        /// The selected priority.
-        /// </summary>
         private string selectedPriority;
-
-        /// <summary>
-        /// The selected verbosity.
-        /// </summary>
         private int selectedVerbosity;
-
-        /// <summary>
-        /// The send file after encode.
-        /// </summary>
         private bool sendFileAfterEncode;
-
-        /// <summary>
-        /// The send file to.
-        /// </summary>
         private string sendFileTo;
-
-        /// <summary>
-        /// The send file to Path.
-        /// </summary>
         private string sendFileToPath;
-
-        /// <summary>
-        /// The vlc path.
-        /// </summary>
         private string vlcPath;
-
-        /// <summary>
-        /// The when done.
-        /// </summary>
         private string whenDone;
-
-        /// <summary>
-        /// The when done options.
-        /// </summary>
         private BindingList<string> whenDoneOptions = new BindingList<string>();
-
-        /// <summary>
-        /// Backing field for clear queue on encode completed.
-        /// </summary>
         private bool clearQueueOnEncodeCompleted;
-
-        /// <summary>
-        /// The options tab that is selected.
-        /// </summary>
         private OptionsTab selectedTab;
-
-        /// <summary>
-        /// Update Message
-        /// </summary>
         private string updateMessage;
-
-        /// <summary>
-        /// Update Available
-        /// </summary>
         private bool updateAvailable;
-
-        /// <summary>
-        /// Download progress backing field.
-        /// </summary>
         private int downloadProgressPercentage;
-
-        /// <summary>
-        /// Backing field for update info.
-        /// </summary>
         private UpdateCheckInformation updateInfo;
-
-        /// <summary>
-        /// The enable process isolation.
-        /// </summary>
-        private bool enableProcessIsolation;
-
-        /// <summary>
-        /// The server port.
-        /// </summary>
-        private int serverPort;
-
-        /// <summary>
-        /// Backing field for EnableLibHb
-        /// </summary>
-        private bool enableLibHb;
-
-        /// <summary>
-        /// The show advanced tab backing field.
-        /// </summary>
         private bool showAdvancedTab;
-
-        /// <summary>
-        /// The enable static preview.
-        /// </summary>
-        private bool enableStaticPreview;
-
-        /// <summary>
-        /// The remove punctuation.
-        /// </summary>
         private bool removePunctuation;
-
-        /// <summary>
-        /// The use system colours for styles.
-        /// </summary>
-        private bool useSystemColoursForStyles;
-
-        /// <summary>
-        /// The reset when done action.
-        /// </summary>
         private bool resetWhenDoneAction;
-
-        /// <summary>
-        /// The selected scaling mode.
-        /// </summary>
         private VideoScaler selectedScalingMode;
-
-        /// <summary>
-        /// The enable dxva decoding.
-        /// </summary>
-        private bool enableDxvaDecoding;
-
-        /// <summary>
-        /// The disable quick sync decoding.
-        /// </summary>
         private bool disableQuickSyncDecoding;
-
-        /// <summary>
-        /// The is cl scaling.
-        /// </summary>
         private bool isClScaling;
+        private bool showQueueInline;
+        private bool pauseOnLowDiskspace;
+
+        private bool useQsvDecodeForNonQsvEnc;
 
         #endregion
 
@@ -330,18 +104,22 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="userSettingService">
         /// The user Setting Service.
         /// </param>
-        /// <param name="shellViewModel">
-        /// The shell View Model.
-        /// </param>
         /// <param name="updateService">
         /// The update Service.
         /// </param>
-        public OptionsViewModel(IUserSettingService userSettingService, IShellViewModel shellViewModel, IUpdateService updateService)
+        /// <param name="aboutViewModel">
+        /// The about View Model.
+        /// </param>
+        /// <param name="errorService">
+        /// The error Service.
+        /// </param>
+        public OptionsViewModel(IUserSettingService userSettingService, IUpdateService updateService, IAboutViewModel aboutViewModel, IErrorService errorService)
         {
             this.Title = "Options";
             this.userSettingService = userSettingService;
-            this.shellViewModel = shellViewModel;
             this.updateService = updateService;
+            this.errorService = errorService;
+            this.AboutViewModel = aboutViewModel;
             this.OnLoad();
 
             this.SelectedTab = OptionsTab.General;
@@ -465,40 +243,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether GrowlAfterEncode.
-        /// </summary>
-        public bool GrowlAfterEncode
-        {
-            get
-            {
-                return this.growlAfterEncode;
-            }
-
-            set
-            {
-                this.growlAfterEncode = value;
-                this.NotifyOfPropertyChange("GrowlAfterEncode");
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets a value indicating whether GrowlAfterQueue.
-        /// </summary>
-        public bool GrowlAfterQueue
-        {
-            get
-            {
-                return this.growlAfterQueue;
-            }
-
-            set
-            {
-                this.growlAfterQueue = value;
-                this.NotifyOfPropertyChange("GrowlAfterQueue");
-            }
-        }
-
         /// <summary>
         /// Gets or sets a value indicating whether SendFileAfterEncode.
         /// </summary>
@@ -585,18 +329,22 @@ namespace HandBrakeWPF.ViewModels
         }
 
         /// <summary>
-        /// Gets or sets a value indicating whether use system colours.
+        /// Gets or sets a value indicating whether show queue inline.
         /// </summary>
-        public bool UseSystemColoursForStylesForStyles
+        public bool ShowQueueInline
         {
             get
             {
-                return this.useSystemColoursForStyles;
+                return this.showQueueInline;
             }
             set
             {
-                this.useSystemColoursForStyles = value;
-                this.NotifyOfPropertyChange(() => UseSystemColoursForStylesForStyles);
+                if (value == this.showQueueInline)
+                {
+                    return;
+                }
+                this.showQueueInline = value;
+                this.NotifyOfPropertyChange(() => this.ShowQueueInline);
             }
         }
 
@@ -650,7 +398,11 @@ namespace HandBrakeWPF.ViewModels
 
             set
             {
-                this.autonameFormat = value;
+                if (this.IsValidAutonameFormat(value, false))
+                {
+                    this.autonameFormat = value;   
+                } 
+
                 this.NotifyOfPropertyChange("AutonameFormat");
             }
         }
@@ -847,6 +599,23 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        /// <summary>
+        /// Gets or sets a value indicating whether HandBrake should pause on low disk space.
+        /// </summary>
+        public bool PauseOnLowDiskspace
+        {
+            get
+            {
+                return this.pauseOnLowDiskspace;
+            }
+
+            set
+            {
+                this.pauseOnLowDiskspace = value;
+                this.NotifyOfPropertyChange(() => this.PauseOnLowDiskspace);
+            }
+        }  
+
         /// <summary>
         /// Gets or sets PriorityLevelOptions.
         /// </summary>
@@ -894,7 +663,30 @@ namespace HandBrakeWPF.ViewModels
             set
             {
                 this.selectedPriority = value;
-                this.NotifyOfPropertyChange("SelectedPriority");
+                this.NotifyOfPropertyChange();
+
+                // Set the Process Priority
+                switch (value)
+                {
+                    case "Realtime":
+                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.RealTime;
+                        break;
+                    case "High":
+                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.High;
+                        break;
+                    case "Above Normal":
+                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.AboveNormal;
+                        break;
+                    case "Normal":
+                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.Normal;
+                        break;
+                    case "Low":
+                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.Idle;
+                        break;
+                    default:
+                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.BelowNormal;
+                        break;
+                }
             }
         }
         #endregion
@@ -935,23 +727,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether disablePresetUpdateCheckNotification.
-        /// </summary>
-        public bool DisablePresetUpdateCheckNotification
-        {
-            get
-            {
-                return this.disablePresetUpdateCheckNotification;
-            }
-
-            set
-            {
-                this.disablePresetUpdateCheckNotification = value;
-                this.NotifyOfPropertyChange("DisablePresetUpdateCheckNotification");
-            }
-        }
-
         /// <summary>
         /// Gets or sets LogVerbosityOptions.
         /// </summary>
@@ -1070,54 +845,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether ClearQueueOnEncodeCompleted.
-        /// </summary>
-        public bool EnableProcessIsolation
-        {
-            get
-            {
-                return this.enableProcessIsolation;
-            }
-            set
-            {
-                this.enableProcessIsolation = value;
-                this.NotifyOfPropertyChange(() => this.EnableProcessIsolation);
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets the server port.
-        /// </summary>
-        public int ServerPort
-        {
-            get
-            {
-                return this.serverPort;
-            }
-            set
-            {
-                this.serverPort = value;
-                this.NotifyOfPropertyChange(() => this.ServerPort);
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets a value indicating whether enable lib hb.
-        /// </summary>
-        public bool EnableLibHb
-        {
-            get
-            {
-                return this.enableLibHb;
-            }
-            set
-            {
-                this.enableLibHb = value;
-                this.NotifyOfPropertyChange(() => this.EnableLibHb);
-            }
-        }
-
         /// <summary>
         /// Gets or sets a value indicating whether enable lib hb.
         /// </summary>
@@ -1134,22 +861,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether enable static preview.
-        /// </summary>
-        public bool EnableStaticPreview
-        {
-            get
-            {
-                return this.enableStaticPreview;
-            }
-            set
-            {
-                this.enableStaticPreview = value;
-                this.NotifyOfPropertyChange(() => this.EnableStaticPreview);
-            }
-        }
-
         #endregion
 
         #region Video
@@ -1171,26 +882,7 @@ namespace HandBrakeWPF.ViewModels
                 }
                 this.disableQuickSyncDecoding = value;
                 this.NotifyOfPropertyChange(() => this.DisableQuickSyncDecoding);
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets a value indicating whether enable dxva decoding.
-        /// </summary>
-        public bool EnableDxvaDecoding
-        {
-            get
-            {
-                return this.enableDxvaDecoding;
-            }
-            set
-            {
-                if (value.Equals(this.enableDxvaDecoding))
-                {
-                    return;
-                }
-                this.enableDxvaDecoding = value;
-                this.NotifyOfPropertyChange(() => this.EnableDxvaDecoding);
+                this.NotifyOfPropertyChange(() => this.IsUseQsvDecAvailable);
             }
         }
 
@@ -1221,6 +913,34 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        /// <summary>
+        /// Gets a value indicating whether is use qsv dec available.
+        /// </summary>
+        public bool IsUseQsvDecAvailable
+        {
+            get
+            {
+                return IsQuickSyncAvailable && !this.DisableQuickSyncDecoding;
+            }
+        }
+
+        /// <summary>
+        /// Gets or sets a value indicating whether to use qsv decode for non qsv encoders
+        /// </summary>
+        public bool UseQSVDecodeForNonQSVEnc
+        {
+            get
+            {
+                return this.useQsvDecodeForNonQsvEnc;
+            }
+            set
+            {
+                if (value == this.useQsvDecodeForNonQsvEnc) return;
+                this.useQsvDecodeForNonQsvEnc = value;
+                this.NotifyOfPropertyChange(() => this.UseQSVDecodeForNonQSVEnc);
+            }
+        }
+
         /// <summary>
         /// Gets the scaling options.
         /// </summary>
@@ -1336,7 +1056,9 @@ namespace HandBrakeWPF.ViewModels
         public void Close()
         {
             this.Save();
-            this.shellViewModel.DisplayWindow(ShellWindow.MainWindow);
+
+            IShellViewModel shellViewModel = IoC.Get<IShellViewModel>();
+            shellViewModel.DisplayWindow(ShellWindow.MainWindow);
         }
 
         /// <summary>
@@ -1344,10 +1066,13 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void BrowseSendFileTo()
         {
-            VistaOpenFileDialog dialog = new VistaOpenFileDialog { Filter = "All files (*.*)|*.*" };
-            dialog.ShowDialog();
-            this.SendFileTo = Path.GetFileNameWithoutExtension(dialog.FileName);
-            this.sendFileToPath = dialog.FileName;
+            VistaOpenFileDialog dialog = new VistaOpenFileDialog { Filter = "All files (*.*)|*.*", FileName = this.sendFileToPath };
+            bool? dialogResult = dialog.ShowDialog();
+            if (dialogResult.HasValue && dialogResult.Value)
+            {
+                this.SendFileTo = Path.GetFileNameWithoutExtension(dialog.FileName);
+                this.sendFileToPath = dialog.FileName;
+            }
         }
 
         /// <summary>
@@ -1355,9 +1080,12 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void BrowseAutoNamePath()
         {
-            VistaFolderBrowserDialog dialog = new VistaFolderBrowserDialog { Description = "Please select a folder.", UseDescriptionForTitle = true };
-            dialog.ShowDialog();
-            this.AutoNameDefaultPath = dialog.SelectedPath;
+            VistaFolderBrowserDialog dialog = new VistaFolderBrowserDialog { Description = "Please select a folder.", UseDescriptionForTitle = true, SelectedPath = this.AutoNameDefaultPath };
+            bool? dialogResult = dialog.ShowDialog();
+            if (dialogResult.HasValue && dialogResult.Value)
+            {
+                this.AutoNameDefaultPath = dialog.SelectedPath;
+            }
         }
 
         /// <summary>
@@ -1365,9 +1093,12 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void BrowseVlcPath()
         {
-            VistaOpenFileDialog dialog = new VistaOpenFileDialog { Filter = "All files (*.exe)|*.exe" };
-            dialog.ShowDialog();
-            this.VLCPath = dialog.FileName;
+            VistaOpenFileDialog dialog = new VistaOpenFileDialog { Filter = "All files (*.exe)|*.exe", FileName = this.VLCPath };
+            bool? dialogResult = dialog.ShowDialog();
+            if (dialogResult.HasValue && dialogResult.Value)
+            {
+                this.VLCPath = dialog.FileName;
+            }
         }
 
         /// <summary>
@@ -1375,9 +1106,12 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void BrowseLogPath()
         {
-            VistaFolderBrowserDialog dialog = new VistaFolderBrowserDialog { Description = "Please select a folder.", UseDescriptionForTitle = true };
-            dialog.ShowDialog();
-            this.LogDirectory = dialog.SelectedPath;
+            VistaFolderBrowserDialog dialog = new VistaFolderBrowserDialog { Description = "Please select a folder.", UseDescriptionForTitle = true, SelectedPath = this.LogDirectory };
+            bool? dialogResult = dialog.ShowDialog();
+            if (dialogResult.HasValue && dialogResult.Value)
+            {
+                this.LogDirectory = dialog.SelectedPath;
+            }
         }
 
         /// <summary>
@@ -1411,7 +1145,7 @@ namespace HandBrakeWPF.ViewModels
         public void DownloadUpdate()
         {
             this.UpdateMessage = "Preparing for Update ...";
-            this.updateService.DownloadFile(this.updateInfo.DownloadFile, this.DownloadComplete, this.DownloadProgress);
+            this.updateService.DownloadFile(this.updateInfo.DownloadFile, this.updateInfo.Signature, this.DownloadComplete, this.DownloadProgress);
         }
 
         /// <summary>
@@ -1438,22 +1172,13 @@ namespace HandBrakeWPF.ViewModels
 
             // Days between update checks
             this.checkForUpdatesFrequencies.Clear();
-            this.checkForUpdatesFrequencies.Add("Daily");
             this.checkForUpdatesFrequencies.Add("Weekly");
             this.checkForUpdatesFrequencies.Add("Monthly");
 
-            // TODO Refactor this.
-            switch (this.userSettingService.GetUserSetting<int>(UserSettingConstants.DaysBetweenUpdateCheck))
+            this.CheckForUpdatesFrequency = this.userSettingService.GetUserSetting<int>(UserSettingConstants.DaysBetweenUpdateCheck);
+            if (this.CheckForUpdatesFrequency > 1)
             {
-                case 1:
-                    this.CheckForUpdatesFrequency = 0;
-                    break;
-                case 7:
-                    this.CheckForUpdatesFrequency = 1;
-                    break;
-                default:
-                    this.CheckForUpdatesFrequency = 2;
-                    break;
+                this.CheckForUpdatesFrequency = 1;
             }
 
             // On Encode Completeion Action
@@ -1469,17 +1194,14 @@ namespace HandBrakeWPF.ViewModels
             if (this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ResetWhenDoneAction))
             {
                 this.WhenDone = "Do nothing";
-                this.userSettingService.SetUserSetting(UserSettingConstants.WhenCompleteAction, "Do nothing");
             }
 
-            this.GrowlAfterEncode = userSettingService.GetUserSetting<bool>(UserSettingConstants.GrowlEncode);
-            this.GrowlAfterQueue = userSettingService.GetUserSetting<bool>(UserSettingConstants.GrowlQueue);
             this.SendFileAfterEncode = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.SendFile);
             this.SendFileTo = Path.GetFileNameWithoutExtension(this.userSettingService.GetUserSetting<string>(UserSettingConstants.SendFileTo)) ?? string.Empty;
             this.SendFileToPath = this.userSettingService.GetUserSetting<string>(UserSettingConstants.SendFileTo) ?? string.Empty;
             this.Arguments = this.userSettingService.GetUserSetting<string>(UserSettingConstants.SendFileToArgs) ?? string.Empty;
-            this.UseSystemColoursForStylesForStyles = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.UseSystemColours);
             this.ResetWhenDoneAction = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ResetWhenDoneAction);
+            this.ShowQueueInline = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowQueueInline);
 
             // #############################
             // Output Settings
@@ -1494,7 +1216,8 @@ namespace HandBrakeWPF.ViewModels
                 this.AutoNameDefaultPath = "Click 'Browse' to set the default location";
 
             // Store auto name format
-            this.AutonameFormat = this.userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNameFormat) ?? string.Empty;
+            string anf = this.userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNameFormat) ?? string.Empty;
+            this.AutonameFormat = this.IsValidAutonameFormat(anf, true) ? anf : "{source}-{title}";
 
             // Use iPod/iTunes friendly .m4v extension for MP4 files.
             this.mp4ExtensionOptions.Clear();
@@ -1521,8 +1244,8 @@ namespace HandBrakeWPF.ViewModels
             // Video
             // #############################
             this.DisableQuickSyncDecoding = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.DisableQuickSyncDecoding);
-            this.EnableDxvaDecoding = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableDxva);
             this.SelectedScalingMode = this.userSettingService.GetUserSetting<VideoScaler>(UserSettingConstants.ScalingMode);
+            this.UseQSVDecodeForNonQSVEnc = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.UseQSVDecodeForNonQSVEnc);
 
             // #############################
             // CLI
@@ -1538,7 +1261,8 @@ namespace HandBrakeWPF.ViewModels
             this.SelectedPriority = userSettingService.GetUserSetting<string>(UserSettingConstants.ProcessPriority);
 
             this.PreventSleep = userSettingService.GetUserSetting<bool>(UserSettingConstants.PreventSleep);
-
+            this.PauseOnLowDiskspace = userSettingService.GetUserSetting<bool>(UserSettingConstants.PauseOnLowDiskspace);
+            
             // Log Verbosity Level
             this.logVerbosityOptions.Clear();
             this.logVerbosityOptions.Add(0);
@@ -1561,7 +1285,6 @@ namespace HandBrakeWPF.ViewModels
 
             // Minimise to Tray
             this.MinimiseToTray = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.MainWindowMinimize);
-            this.DisablePresetUpdateCheckNotification = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.PresetNotification);
             this.ClearQueueOnEncodeCompleted = userSettingService.GetUserSetting<bool>(UserSettingConstants.ClearCompletedFromQueue);
             this.ShowAdvancedTab = userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowAdvancedTab);
 
@@ -1593,13 +1316,14 @@ namespace HandBrakeWPF.ViewModels
             // Use dvdnav
             this.DisableLibdvdNav = userSettingService.GetUserSetting<bool>(UserSettingConstants.DisableLibDvdNav);
 
-            this.EnableStaticPreview = userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableStaticPreview);            
+        }
 
-            int port;
-            int.TryParse(userSettingService.GetUserSetting<string>(UserSettingConstants.ServerPort), out port);
-            this.ServerPort = port;
-            this.EnableProcessIsolation = userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableProcessIsolation);
-            this.EnableLibHb = userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableLibHb);
+        /// <summary>
+        /// Some settings can be changed outside of this window. This will refresh their UI controls.
+        /// </summary>
+        public void UpdateSettings()
+        {
+            this.WhenDone = userSettingService.GetUserSetting<string>("WhenCompleteAction");
         }
 
         /// <summary>
@@ -1611,13 +1335,11 @@ namespace HandBrakeWPF.ViewModels
             this.userSettingService.SetUserSetting(UserSettingConstants.UpdateStatus, this.CheckForUpdates);
             this.userSettingService.SetUserSetting(UserSettingConstants.DaysBetweenUpdateCheck, this.CheckForUpdatesFrequency);
             this.userSettingService.SetUserSetting(UserSettingConstants.WhenCompleteAction, this.WhenDone);
-            this.userSettingService.SetUserSetting(UserSettingConstants.GrowlQueue, this.GrowlAfterQueue);
-            this.userSettingService.SetUserSetting(UserSettingConstants.GrowlEncode, this.GrowlAfterEncode);
             this.userSettingService.SetUserSetting(UserSettingConstants.SendFileTo, this.SendFileToPath);
             this.userSettingService.SetUserSetting(UserSettingConstants.SendFile, this.SendFileAfterEncode);
             this.userSettingService.SetUserSetting(UserSettingConstants.SendFileToArgs, this.Arguments);
-            this.userSettingService.SetUserSetting(UserSettingConstants.UseSystemColours, this.UseSystemColoursForStylesForStyles);
             this.userSettingService.SetUserSetting(UserSettingConstants.ResetWhenDoneAction, this.ResetWhenDoneAction);
+            this.userSettingService.SetUserSetting(UserSettingConstants.ShowQueueInline, this.ShowQueueInline);
 
             /* Output Files */
             this.userSettingService.SetUserSetting(UserSettingConstants.AutoNaming, this.AutomaticallyNameFiles);
@@ -1630,15 +1352,16 @@ namespace HandBrakeWPF.ViewModels
 
             /* Previews */
             this.userSettingService.SetUserSetting(UserSettingConstants.VLCPath, this.VLCPath);
-            
+
             /* Video */
             this.userSettingService.SetUserSetting(UserSettingConstants.DisableQuickSyncDecoding, this.DisableQuickSyncDecoding);
-            this.userSettingService.SetUserSetting(UserSettingConstants.EnableDxva, this.EnableDxvaDecoding);
             this.userSettingService.SetUserSetting(UserSettingConstants.ScalingMode, this.SelectedScalingMode);
+            this.userSettingService.SetUserSetting(UserSettingConstants.UseQSVDecodeForNonQSVEnc, this.UseQSVDecodeForNonQSVEnc);
 
             /* System and Logging */
             userSettingService.SetUserSetting(UserSettingConstants.ProcessPriority, this.SelectedPriority);
             userSettingService.SetUserSetting(UserSettingConstants.PreventSleep, this.PreventSleep);
+            userSettingService.SetUserSetting(UserSettingConstants.PauseOnLowDiskspace, this.PauseOnLowDiskspace);
             userSettingService.SetUserSetting(UserSettingConstants.Verbosity, this.SelectedVerbosity);
             userSettingService.SetUserSetting(UserSettingConstants.SaveLogWithVideo, this.CopyLogToEncodeDirectory);
             userSettingService.SetUserSetting(UserSettingConstants.SaveLogToCopyDirectory, this.CopyLogToSepcficedLocation);
@@ -1647,12 +1370,10 @@ namespace HandBrakeWPF.ViewModels
 
             /* Advanced */
             userSettingService.SetUserSetting(UserSettingConstants.MainWindowMinimize, this.MinimiseToTray);
-            userSettingService.SetUserSetting(UserSettingConstants.PresetNotification, this.DisablePresetUpdateCheckNotification);
             userSettingService.SetUserSetting(UserSettingConstants.ClearCompletedFromQueue, this.ClearQueueOnEncodeCompleted);
             userSettingService.SetUserSetting(UserSettingConstants.PreviewScanCount, this.SelectedPreviewCount);
             userSettingService.SetUserSetting(UserSettingConstants.X264Step, double.Parse(this.SelectedGranulairty, CultureInfo.InvariantCulture));
             userSettingService.SetUserSetting(UserSettingConstants.ShowAdvancedTab, this.ShowAdvancedTab);
-            userSettingService.SetUserSetting(UserSettingConstants.EnableStaticPreview, this.EnableStaticPreview);
 
             int value;
             if (int.TryParse(this.MinLength.ToString(CultureInfo.InvariantCulture), out value))
@@ -1661,9 +1382,6 @@ namespace HandBrakeWPF.ViewModels
             }
 
             userSettingService.SetUserSetting(UserSettingConstants.DisableLibDvdNav, this.DisableLibdvdNav);
-            userSettingService.SetUserSetting(UserSettingConstants.EnableProcessIsolation, this.EnableProcessIsolation);
-            userSettingService.SetUserSetting(UserSettingConstants.ServerPort, this.ServerPort.ToString(CultureInfo.InvariantCulture));
-            userSettingService.SetUserSetting(UserSettingConstants.EnableLibHb, this.EnableLibHb);
         }
 
         /// <summary>
@@ -1677,17 +1395,17 @@ namespace HandBrakeWPF.ViewModels
             this.updateInfo = info;
             if (info.NewVersionAvailable)
             {
-                this.UpdateMessage = "A New Update is Available!";
+                this.UpdateMessage = Resources.OptionsViewModel_NewUpdate;
                 this.UpdateAvailable = true;
             }
             else if (Environment.Is64BitOperatingSystem && !System.Environment.Is64BitProcess)
             {
-                this.UpdateMessage = "Your system supports the 64bit version of HandBrake! This offers performance and stability improvements over this 32bit version.";
+                this.UpdateMessage = Resources.OptionsViewModel_64bitAvailable;
                 this.UpdateAvailable = true;
             }
             else
             {
-                this.UpdateMessage = "There are no new updates at this time.";
+                this.UpdateMessage = Resources.OptionsViewModel_NoNewUpdates;
                 this.UpdateAvailable = false;
             }
         }
@@ -1703,7 +1421,7 @@ namespace HandBrakeWPF.ViewModels
             if (info.TotalBytes == 0 || info.BytesRead == 0)
             {
                 this.UpdateAvailable = false;
-                this.UpdateMessage = info.WasSuccessful ? "Update Downloaded" : "Update Service Unavailable. You can try downloading the update from https://handbrake.fr";
+                this.UpdateMessage = info.WasSuccessful ? Resources.OptionsViewModel_UpdateDownloaded : Resources.OptionsViewModel_UpdateServiceUnavailable;
                 return;
             }
 
@@ -1724,10 +1442,13 @@ namespace HandBrakeWPF.ViewModels
         private void DownloadComplete(DownloadStatus info)
         {
             this.UpdateAvailable = false;
-            this.UpdateMessage = info.WasSuccessful ? "Update Downloaded" : "Update Failed. You can try downloading the update from https://handbrake.fr";
+            this.UpdateMessage = info.WasSuccessful ? Resources.OptionsViewModel_UpdateDownloaded : info.Message;
 
-            Process.Start(Path.Combine(Path.GetTempPath(), "handbrake-setup.exe"));
-            Execute.OnUIThread(() => Application.Current.Shutdown());
+            if (info.WasSuccessful)
+            {
+                Process.Start(Path.Combine(Path.GetTempPath(), "handbrake-setup.exe"));
+                Execute.OnUIThread(() => Application.Current.Shutdown());
+            }
         }
 
         /// <summary>
@@ -1740,5 +1461,33 @@ namespace HandBrakeWPF.ViewModels
         {
             this.SelectedTab = tab;
         }
+
+        /// <summary>
+        /// Validate the Autoname Fileformat string
+        /// </summary>
+        /// <param name="input">The format string</param>
+        /// <param name="isSilent">Don't show an error dialog if true.</param>
+        /// <returns>True if valid</returns>
+        private bool IsValidAutonameFormat(string input, bool isSilent)
+        {
+            foreach (var characterToTest in input)
+            {
+                // we binary search for the character in the invalid set. This should be lightning fast.
+                if (Array.BinarySearch(Path.GetInvalidFileNameChars(), characterToTest) >= 0)
+                {
+                    if (!isSilent)
+                    {
+                        this.errorService.ShowMessageBox(
+                            ResourcesUI.OptionsView_InvalidFileFormatChars,
+                            Resources.Error,
+                            MessageBoxButton.OK,
+                            MessageBoxImage.Error);
+                    }
+                    return false;
+                }
+            }
+
+            return true;
+        }
     }
 }
\ No newline at end of file
