@@ -13,16 +13,18 @@ namespace HandBrakeWPF.ViewModels
     using System.Collections.Generic;
     using System.Globalization;
 
-    using HandBrake.ApplicationServices.Model;
-    using HandBrake.ApplicationServices.Parsing;
-    using HandBrake.Interop.Model;
-    using HandBrake.Interop.Model.Encoding;
+    using HandBrake.ApplicationServices.Interop.Model;
+    using HandBrake.ApplicationServices.Interop.Model.Encoding;
 
     using HandBrakeWPF.Helpers;
+    using HandBrakeWPF.Properties;
+    using HandBrakeWPF.Services.Presets.Model;
+    using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
 
-    using Size = System.Drawing.Size;
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
+    using PresetPictureSettingsMode = HandBrakeWPF.Model.Picture.PresetPictureSettingsMode;
 
     /// <summary>
     /// The Picture Settings View Model
@@ -109,6 +111,11 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         private Title currentTitle;
 
+        /// <summary>
+        /// The scanned source.
+        /// </summary>
+        private Source scannedSource;
+
         #endregion
 
         #region Constructors and Destructors
@@ -118,6 +125,7 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public PictureSettingsViewModel()
         {
+            this.sourceResolution = new Size(0, 0);
             this.Task = new EncodeTask();
             this.Init();
         }
@@ -138,7 +146,7 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return new List<Anamorphic> { Anamorphic.None, Anamorphic.Strict, Anamorphic.Loose, Anamorphic.Custom };
+                return new List<Anamorphic> { Anamorphic.None, Anamorphic.Automatic, Anamorphic.Loose }; // , Anamorphic.Custom   TODO Re-enable one the UI is re-worked.
             }
         }
 
@@ -323,17 +331,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets a value indicating whether is picture preview enabled.
-        /// </summary>
-        public bool IsPicturePreviewEnabled
-        {
-            get
-            {
-                return this.UserSettingService.GetUserSetting<bool>(UserSettingConstants.EnableStaticPreview);
-            }
-        }
-
         #endregion
 
         #region Task Properties
@@ -646,21 +643,34 @@ namespace HandBrakeWPF.ViewModels
                     }             
 
                     // Set the width, then check the height doesn't breach the max height and correct if necessary.
-                    int width = this.GetModulusValue(this.GetRes((this.sourceResolution.Width - this.CropLeft - this.CropRight), preset.Task.MaxWidth)); 
-                    this.Width = width;
+                    int width = this.GetModulusValue(this.GetRes((this.sourceResolution.Width - this.CropLeft - this.CropRight), this.MaxWidth));
+                    int height = this.GetModulusValue(this.GetRes((this.sourceResolution.Height - this.CropTop - this.CropBottom), this.MaxHeight));
+
+                    // Set the backing fields to avoid triggering recalulation until both are set.
+                    this.Task.Width = width;
+                    this.Task.Height = height;
+
+                    // Trigger a Recalc
+                    this.RecaulcatePictureSettingsProperties(ChangedPictureField.Width);
+
+                    // Update the UI
+                    this.NotifyOfPropertyChange(() => this.Width);
+                    this.NotifyOfPropertyChange(() => this.Height);
 
-                    // If we have a max height, make sure we havn't breached it.
-                    int height = this.GetModulusValue(this.GetRes((this.sourceResolution.Height - this.CropTop - this.CropBottom), preset.Task.MaxHeight));
-                    if (preset.Task.MaxHeight.HasValue && this.Height > preset.Task.MaxHeight.Value)
-                    {
-                        this.Height = height;
-                    }
                     break;
                 case PresetPictureSettingsMode.None:
                     // Do Nothing except reset the Max Width/Height
                     this.MaxWidth = this.sourceResolution.Width;
                     this.MaxHeight = this.sourceResolution.Height;
                     this.SelectedAnamorphicMode = preset.Task.Anamorphic;
+
+                    if (this.Width > this.MaxWidth)
+                    {
+                        // Trigger a Recalc
+                        this.Task.Width = this.GetModulusValue(this.GetRes((this.sourceResolution.Width - this.CropLeft - this.CropRight), this.MaxWidth));
+                        this.RecaulcatePictureSettingsProperties(ChangedPictureField.Width);
+                    }
+
                     break;
             }
 
@@ -709,6 +719,9 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Setup this window for a new source
         /// </summary>
+        /// <param name="source">
+        /// The source.
+        /// </param>
         /// <param name="title">
         /// The title.
         /// </param>
@@ -718,11 +731,13 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="task">
         /// The task.
         /// </param>
-        public void SetSource(Title title, Preset preset, EncodeTask task)
+        public void SetSource(Source source, Title title, Preset preset, EncodeTask task)
         {
             this.currentTitle = title;
             this.Task = task;
 
+            this.scannedSource = source;
+
             if (title != null)
             {
                 // Set cached info
@@ -747,44 +762,42 @@ namespace HandBrakeWPF.ViewModels
                     this.IsCustomCrop = true;
                 }
 
+                // Set the Max Width / Height available to the user controls.
+                // Preset Max is null for None / SourceMax
+                this.MaxWidth = preset.Task.MaxWidth ?? this.sourceResolution.Width;
+                if (this.sourceResolution.Width < this.MaxWidth)
+                {
+                    this.MaxWidth = this.sourceResolution.Width;
+                }
+
+                this.MaxHeight = preset.Task.MaxHeight ?? this.sourceResolution.Height;
+                if (this.sourceResolution.Height < this.MaxHeight)
+                {
+                    this.MaxHeight = this.sourceResolution.Height;
+                }
+
+                // Set the W/H
                 if (preset.PictureSettingsMode == PresetPictureSettingsMode.None)
                 {
-                    // We have no instructions, so simply set it to the source.
                     this.Task.Width = this.GetModulusValue(this.sourceResolution.Width - this.CropLeft - this.CropRight);
-                    this.MaintainAspectRatio = true;
+                    this.Task.Height = this.GetModulusValue(this.sourceResolution.Height - this.CropTop - this.CropBottom);
                 }
-                else
+                else if (preset.PictureSettingsMode == PresetPictureSettingsMode.SourceMaximum)
+                {
+                    this.Task.Width = this.GetModulusValue(this.sourceResolution.Width - this.CropLeft - this.CropRight);
+                    this.Task.Height = this.GetModulusValue(this.sourceResolution.Height - this.CropTop - this.CropBottom);
+                    this.MaintainAspectRatio = preset.Task.KeepDisplayAspect;
+                }
+                else // Custom
                 {
-                    // Set the Max Width / Height available to the user controls
-                    if (this.sourceResolution.Width < this.MaxWidth)
-                    {
-                        this.MaxWidth = this.sourceResolution.Width;
-                    }
-                    else if (this.sourceResolution.Width > this.MaxWidth)
-                    {
-                        this.MaxWidth = preset.Task.MaxWidth ?? this.sourceResolution.Width;
-                    }
-
-                    if (this.sourceResolution.Height < this.MaxHeight)
-                    {
-                        this.MaxHeight = this.sourceResolution.Height;
-                    }
-                    else if (this.sourceResolution.Height > this.MaxHeight)
-                    {
-                        this.MaxHeight = preset.Task.MaxHeight ?? this.sourceResolution.Height;
-                    }
-
                     // Set the Width, and Maintain Aspect ratio. That should calc the Height for us.
-                    if (this.SelectedAnamorphicMode == Anamorphic.None)
-                    {
-                        this.Task.Width = preset.Task.Width ?? (this.MaxWidth - this.CropLeft - this.CropRight);
-                        // Note: This will be auto-corrected in the property if it's too large.
-                    }
-                    else
-                    {
-                        this.Task.Width = preset.Task.Width ?? this.MaxWidth;
-                    }
+                    this.Task.Width = this.GetModulusValue(this.MaxWidth - this.CropLeft - this.CropRight);
 
+                    if (this.SelectedAnamorphicMode != Anamorphic.Loose)
+                    {
+                        this.Task.Height = this.GetModulusValue(this.MaxHeight - this.CropTop - this.CropBottom);
+                    }
+ 
                     // If our height is too large, let it downscale the width for us by setting the height to the lower value.
                     if (!this.MaintainAspectRatio && this.Height > this.MaxHeight)
                     {
@@ -794,10 +807,9 @@ namespace HandBrakeWPF.ViewModels
 
                 // Set Screen Controls
                 this.SourceInfo = string.Format(
-                    "{0}x{1}, Aspect Ratio: {2:0.00}, PAR: {3}/{4}",
+                    "{0}x{1}, PAR: {2}/{3}",
                     title.Resolution.Width,
                     title.Resolution.Height,
-                    title.AspectRatio,
                     title.ParVal.Width,
                     title.ParVal.Height);
 
@@ -807,20 +819,6 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.Task);
         }
 
-        /// <summary>
-        /// The preview image.
-        /// Experimental Feature => In-Progress
-        /// </summary>
-        public void PreviewImage()
-        {
-            if (!string.IsNullOrEmpty(this.Task.Source))
-            {
-                this.StaticPreviewViewModel.IsOpen = true;
-                this.StaticPreviewViewModel.UpdatePreviewFrame(this.Task);
-                this.WindowManager.ShowWindow(this.StaticPreviewViewModel);
-            }
-        }
-
         #endregion
 
         #region Methods
@@ -937,32 +935,16 @@ namespace HandBrakeWPF.ViewModels
 
             // Step 2, For the changed field, call hb_set_anamorphic_size and process the results.
             PictureSize.AnamorphicResult result = PictureSize.hb_set_anamorphic_size2(this.GetPictureSettings(), this.GetPictureTitleInfo(), setting);
-
-            switch (this.SelectedAnamorphicMode)
-            {
-                case Anamorphic.None:
-                    this.Task.Width = result.OutputWidth;
-                    this.Task.Height = result.OutputHeight;
-                    break;
-                case Anamorphic.Strict:
-                    this.Task.Width = 0;
-                    this.Task.Height = 0;
-                    break;
-                case Anamorphic.Loose:
-                    this.Task.Width = result.OutputWidth;
-                    this.Task.Height = 0;
-                    break;
-                case Anamorphic.Custom:
-                    this.Task.Width = result.OutputWidth;
-                    this.Task.Height = result.OutputHeight;
-                    break;
-            }
+            this.Task.Width = result.OutputWidth;
+            this.Task.Height = result.OutputHeight;
+            this.Task.PixelAspectX = (int)Math.Round(result.OutputParWidth, 0);
+            this.Task.PixelAspectY = (int)Math.Round(result.OutputParHeight, 0);
 
             // Step 3, Set the display width label to indicate the output.
             double dispWidth = Math.Round((result.OutputWidth * result.OutputParWidth / result.OutputParHeight), 0);
-            this.DisplaySize = this.sourceResolution.IsEmpty
+            this.DisplaySize = this.sourceResolution == null || this.sourceResolution.IsEmpty
                            ? string.Empty
-                           : string.Format("Storage: {0}x{1}, Display: {2}x{3}", result.OutputWidth, result.OutputHeight, dispWidth, result.OutputHeight);
+                           : string.Format(Resources.PictureSettingsViewModel_StorageDisplayLabel, dispWidth, result.OutputHeight, this.ParWidth, this.ParHeight);
 
             // Step 4, Force an update on all the UI elements.
             this.NotifyOfPropertyChange(() => this.Width);
@@ -979,7 +961,7 @@ namespace HandBrakeWPF.ViewModels
             // Step 5, Update the Preview
             if (delayedPreviewprocessor != null && this.Task != null && this.StaticPreviewViewModel != null && this.StaticPreviewViewModel.IsOpen)
             {
-                delayedPreviewprocessor.PerformTask(() => this.StaticPreviewViewModel.UpdatePreviewFrame(this.Task), 800);
+                delayedPreviewprocessor.PerformTask(() => this.StaticPreviewViewModel.UpdatePreviewFrame(this.Task, this.scannedSource), 800);
             }
         }
 
@@ -1001,11 +983,11 @@ namespace HandBrakeWPF.ViewModels
                     this.ShowDisplaySize = true;
                     this.ShowKeepAR = true;
                     break;
-                case Anamorphic.Strict:
-                    this.WidthControlEnabled = false;
-                    this.HeightControlEnabled = false;
+                case Anamorphic.Automatic:
+                    this.WidthControlEnabled = true;
+                    this.HeightControlEnabled = true;
                     this.ShowCustomAnamorphicControls = false;
-                    this.ShowModulus = false;
+                    this.ShowModulus = true;
                     this.ShowKeepAR = false;
                     break;
 
