@@ -14,10 +14,11 @@ namespace HandBrakeWPF.ViewModels
     using System.ComponentModel;
     using System.Linq;
 
-    using HandBrake.ApplicationServices.Parsing;
-
     using HandBrakeWPF.Model;
+    using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Presets.Model;
+    using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     /// <summary>
@@ -25,36 +26,28 @@ namespace HandBrakeWPF.ViewModels
     /// </summary>
     public class QueueSelectionViewModel : ViewModelBase, IQueueSelectionViewModel
     {
-        /// <summary>
-        /// The error service.
-        /// </summary>
         private readonly IErrorService errorService;
-
-        /// <summary>
-        /// The ordered by duration.
-        /// </summary>
+        private readonly IUserSettingService userSettingService;
         private bool orderedByDuration;
-
-        /// <summary>
-        /// The ordered by title.
-        /// </summary>
         private bool orderedByTitle;
-
-        /// <summary>
-        /// The add to queue.
-        /// </summary>
         private Action<IEnumerable<SelectionTitle>> addToQueue;
 
+        private string currentPreset;
+
         /// <summary>
         /// Initializes a new instance of the <see cref="QueueSelectionViewModel"/> class. 
         /// </summary>
         /// <param name="errorService">
         /// The Error Service
         /// </param>
-        public QueueSelectionViewModel(IErrorService errorService)
+        /// <param name="userSettingService">
+        /// The user Setting Service.
+        /// </param>
+        public QueueSelectionViewModel(IErrorService errorService, IUserSettingService userSettingService)
         {
             this.errorService = errorService;
-            this.Title = "Add to Queue";
+            this.userSettingService = userSettingService;
+            this.Title = Resources.QueueSelectionViewModel_AddToQueue;
             this.TitleList = new BindingList<SelectionTitle>();
             this.OrderedByTitle = true;
         }
@@ -69,6 +62,26 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public BindingList<SelectionTitle> TitleList { get; set; }
 
+        /// <summary>
+        /// Gets or sets the current preset.
+        /// </summary>
+        public string CurrentPreset
+        {
+            get
+            {
+                return this.currentPreset;
+            }
+            set
+            {
+                if (value == this.currentPreset)
+                {
+                    return;
+                }
+                this.currentPreset = value;
+                this.NotifyOfPropertyChange(() => this.CurrentPreset);
+            }
+        }
+
         /// <summary>
         /// Gets or sets a value indicating whether ordered by title.
         /// </summary>
@@ -110,7 +123,7 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return this.UserSettingService.GetUserSetting<bool>(UserSettingConstants.AutoNaming);
+                return this.userSettingService.GetUserSetting<bool>(UserSettingConstants.AutoNaming);
             }
         }
 
@@ -196,7 +209,10 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="addAction">
         /// The add Action.
         /// </param>
-        public void Setup(Source scannedSource, string srcName, Action<IEnumerable<SelectionTitle>> addAction)
+        /// <param name="preset">
+        /// The preset.
+        /// </param>
+        public void Setup(Source scannedSource, string srcName, Action<IEnumerable<SelectionTitle>> addAction, Preset preset)
         {
             this.TitleList.Clear();
             this.addToQueue = addAction;
@@ -214,6 +230,11 @@ namespace HandBrakeWPF.ViewModels
                 }
             }
 
+            if (preset != null)
+            {
+                this.CurrentPreset = string.Format(ResourcesUI.QueueSelection_UsingPreset, preset.Name);
+            }
+
             this.NotifyOfPropertyChange(() => this.IsAutoNamingEnabled);
         }
     }
