@@ -10,71 +10,44 @@
 namespace HandBrakeWPF.ViewModels
 {
     using System;
-    using System.Collections.ObjectModel;
+    using System.Collections.Generic;
     using System.ComponentModel;
+    using System.IO;
+    using System.Linq;
     using System.Windows;
 
     using Caliburn.Micro;
 
-    using HandBrake.ApplicationServices;
-    using HandBrake.ApplicationServices.EventArgs;
-    using HandBrake.ApplicationServices.Model;
-    using HandBrake.ApplicationServices.Services.Interfaces;
-
+    using HandBrakeWPF.EventArgs;
+    using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Queue.Interfaces;
+    using HandBrakeWPF.Services.Queue.Model;
     using HandBrakeWPF.ViewModels.Interfaces;
 
-    using Ookii.Dialogs.Wpf;
+    using Microsoft.Win32;
+
+    using EncodeCompletedEventArgs = HandBrakeWPF.Services.Encode.EventArgs.EncodeCompletedEventArgs;
+    using EncodeProgressEventArgs = HandBrakeWPF.Services.Encode.EventArgs.EncodeProgressEventArgs;
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
 
     /// <summary>
     /// The Preview View Model
     /// </summary>
     public class QueueViewModel : ViewModelBase, IQueueViewModel
     {
-        /*
-         
-         * TODO FIX THE DRAP/DROP ADORNER!
-         */
-
-
-
         #region Constants and Fields
 
-        /// <summary>
-        /// The Error Service Backing field
-        /// </summary>
         private readonly IErrorService errorService;
-
-        /// <summary>
-        /// The User Setting Service Backing Field.
-        /// </summary>
         private readonly IUserSettingService userSettingService;
-
-        /// <summary>
-        /// Queue Processor Backing field
-        /// </summary>
         private readonly IQueueProcessor queueProcessor;
-
-        /// <summary>
-        /// IsEncoding Backing field
-        /// </summary>
         private bool isEncoding;
-
-        /// <summary>
-        /// Job Status Backing field.
-        /// </summary>
         private string jobStatus;
-
-        /// <summary>
-        /// Jobs pending backing field
-        /// </summary>
         private string jobsPending;
-
-        /// <summary>
-        /// Backing field for the when done action description
-        /// </summary>
         private string whenDoneAction;
 
+        private bool isQueueRunning;
+
         #endregion
 
         #region Constructors and Destructors
@@ -82,9 +55,6 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Initializes a new instance of the <see cref="QueueViewModel"/> class.
         /// </summary>
-        /// <param name="windowManager">
-        /// The window manager.
-        /// </param>
         /// <param name="userSettingService">
         /// The user Setting Service.
         /// </param>
@@ -94,14 +64,19 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="errorService">
         /// The Error Service 
         /// </param>
-        public QueueViewModel(IWindowManager windowManager, IUserSettingService userSettingService, IQueueProcessor queueProcessor, IErrorService errorService)
+        public QueueViewModel(IUserSettingService userSettingService, IQueueProcessor queueProcessor, IErrorService errorService)
         {
             this.userSettingService = userSettingService;
             this.queueProcessor = queueProcessor;
             this.errorService = errorService;
-            this.Title = "Queue";
-            this.JobsPending = "No encodes pending";
-            this.JobStatus = "There are no jobs currently encoding";
+            this.Title = Resources.QueueViewModel_Queue;
+            this.JobsPending = Resources.QueueViewModel_NoEncodesPending;
+            this.JobStatus = Resources.QueueViewModel_NoJobsPending;
+            this.SelectedItems = new BindingList<QueueTask>();
+            this.DisplayName = "Queue";
+            this.IsQueueRunning = false;
+            
+            this.WhenDoneAction = this.userSettingService.GetUserSetting<string>(UserSettingConstants.WhenCompleteAction);
         }
 
         #endregion
@@ -109,19 +84,19 @@ namespace HandBrakeWPF.ViewModels
         #region Properties
 
         /// <summary>
-        /// Gets or sets a value indicating whether IsEncoding.
+        /// Gets or sets a value indicating whether the Queue is paused or not..
         /// </summary>
-        public bool IsEncoding
+        public bool IsQueueRunning
         {
             get
             {
-                return this.isEncoding;
+                return this.isQueueRunning;
             }
-
             set
             {
-                this.isEncoding = value;
-                this.NotifyOfPropertyChange(() => IsEncoding);
+                if (value == this.isQueueRunning) return;
+                this.isQueueRunning = value;
+                this.NotifyOfPropertyChange(() => this.IsQueueRunning);
             }
         }
 
@@ -186,6 +161,11 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        /// <summary>
+        /// Gets or sets the selected items.
+        /// </summary>
+        public BindingList<QueueTask> SelectedItems { get; set; }
+
         #endregion
 
         #region Public Methods
@@ -197,9 +177,30 @@ namespace HandBrakeWPF.ViewModels
         /// The action.
         /// </param>
         public void WhenDone(string action)
+        {
+            this.WhenDone(action, true);
+        }
+
+        /// <summary>
+        /// Update the When Done Setting
+        /// </summary>
+        /// <param name="action">
+        /// The action.
+        /// </param>
+        /// <param name="saveChange">
+        /// Save the change to the setting. Use false when updating UI.
+        /// </param>
+        public void WhenDone(string action, bool saveChange)
         {
             this.WhenDoneAction = action;
-            this.userSettingService.SetUserSetting(ASUserSettingConstants.WhenCompleteAction, action);
+
+            if (saveChange)
+            {
+                this.userSettingService.SetUserSetting(UserSettingConstants.WhenCompleteAction, action);
+            }
+
+            IOptionsViewModel ovm = IoC.Get<IOptionsViewModel>();
+            ovm.UpdateSettings();
         }
 
         /// <summary>
@@ -208,7 +209,7 @@ namespace HandBrakeWPF.ViewModels
         public void Clear()
         {
             MessageBoxResult result = this.errorService.ShowMessageBox(
-                "Are you sure you wish to clear the queue?", "Confirm", MessageBoxButton.YesNo, MessageBoxImage.Warning);
+                Resources.QueueViewModel_ClearQueueConfrimation, Resources.Confirm, MessageBoxButton.YesNo, MessageBoxImage.Warning);
             if (result == MessageBoxResult.Yes)
             {
                 this.queueProcessor.Clear();
@@ -237,35 +238,95 @@ namespace HandBrakeWPF.ViewModels
         public override void OnLoad()
         {
             // Setup the window to the correct state.
-            this.IsEncoding = this.queueProcessor.EncodeService.IsEncoding;
-            this.JobsPending = string.Format("{0} jobs pending", this.queueProcessor.Count);
+            this.IsQueueRunning = this.queueProcessor.EncodeService.IsEncoding;
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
 
             base.OnLoad();
         }
 
         /// <summary>
-        /// Pause Encode
+        /// Can Pause the Queue.
+        /// Used by Caliburn Micro to enable/disable the context menu item.
         /// </summary>
-        public void PauseEncode()
+        /// <returns>
+        /// True when we can pause the queue.
+        /// </returns>
+        public bool CanPauseQueue()
+        {
+            return this.IsQueueRunning;
+        }
+
+        /// <summary>
+        /// Pause the Queue
+        /// </summary>
+        public void PauseQueue()
         {
             this.queueProcessor.Pause();
+
+            this.JobStatus = Resources.QueueViewModel_QueuePending;
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
+            this.IsQueueRunning = false;
+
+            MessageBox.Show(Resources.QueueViewModel_QueuePauseNotice, Resources.QueueViewModel_Queue, 
+                MessageBoxButton.OK, MessageBoxImage.Information);
+        }
+
+        /// <summary>
+        /// Pause the Queue
+        /// </summary>
+        /// <remarks>
+        /// Prevents evaluation of CanPauseQueue
+        /// </remarks>
+        public void PauseQueueToolbar()
+        {
+            this.PauseQueue();
+        }
+
+        /// <summary>
+        /// The remove selected jobs.
+        /// </summary>
+        public void RemoveSelectedJobs()
+        {
+            MessageBoxResult result =
+                  this.errorService.ShowMessageBox(
+                      Resources.QueueViewModel_DelSelectedJobConfirmation,
+                      Resources.Question,
+                      MessageBoxButton.YesNo,
+                      MessageBoxImage.Question);
+
+            if (result == MessageBoxResult.No)
+            {
+                return;
+            }
+
+            List<QueueTask> tasksToRemove = this.SelectedItems.ToList();
+            foreach (QueueTask job in tasksToRemove)
+            {
+                this.RemoveJob(job);
+            }
         }
 
         /// <summary>
         /// Remove a Job from the queue
         /// </summary>
-        /// <param name="task">
+        /// <param name="queueTask">
         /// The Job to remove from the queue
         /// </param>
-        public void RemoveJob(QueueTask task)
+        public void RemoveJob(object queueTask)
         {
+            QueueTask task = queueTask as QueueTask;
+            if (task == null)
+            {
+                return;
+            }
+
             if (task.Status == QueueItemStatus.InProgress)
             {
                 MessageBoxResult result =
                     this.errorService.ShowMessageBox(
-                        "This encode is currently in progress. If you delete it, the encode will be stopped. Are you sure you wish to proceed?",
-                        "Warning",
-                        MessageBoxButton.YesNo,
+                        Resources.QueueViewModel_JobCurrentlyRunningWarning, 
+                        Resources.Warning, 
+                        MessageBoxButton.YesNo, 
                         MessageBoxImage.Question);
 
                 if (result == MessageBoxResult.Yes)
@@ -290,22 +351,38 @@ namespace HandBrakeWPF.ViewModels
         {
             task.Status = QueueItemStatus.Waiting;
             this.queueProcessor.BackupQueue(null);
-            this.JobsPending = string.Format("{0} jobs pending", this.queueProcessor.Count);
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
+        }
+
+        /// <summary>
+        /// Can Start Encoding.
+        /// Used by Caliburn Micro to enable/disable the context menu item.
+        /// </summary>
+        /// <returns>
+        /// True when we can start encoding.
+        /// </returns>
+        public bool CanStartQueue()
+        {
+            return !this.IsQueueRunning;
         }
 
         /// <summary>
         /// Start Encode
         /// </summary>
-        public void StartEncode()
+        public void StartQueue()
         {
             if (this.queueProcessor.Count == 0)
             {
                 this.errorService.ShowMessageBox(
-                    "There are no pending jobs.", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
+                    Resources.QueueViewModel_NoPendingJobs, Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
                 return;
             }
 
-            this.queueProcessor.Start();
+            this.JobStatus = Resources.QueueViewModel_QueueStarted;
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
+            this.IsQueueRunning = true;
+
+            this.queueProcessor.Start(userSettingService.GetUserSetting<bool>(UserSettingConstants.ClearCompletedFromQueue));
         }
 
         /// <summary>
@@ -313,16 +390,25 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void Export()
         {
-            VistaSaveFileDialog dialog = new VistaSaveFileDialog
+            SaveFileDialog dialog = new SaveFileDialog
                 {
-                    Filter = "HandBrake Queue Files (*.hbq)|*.hbq",
-                    OverwritePrompt = true,
-                    DefaultExt = ".hbq",
+                    Filter = "Legacy Queue Files (*.hbq)|*.hbq|Json for CLI (*.json)|*.json", 
+                    OverwritePrompt = true, 
+                    DefaultExt = ".hbq", 
                     AddExtension = true
                 };
-            dialog.ShowDialog();
 
-            this.queueProcessor.BackupQueue(dialog.FileName);
+            if (dialog.ShowDialog() == true)
+            {
+                if (Path.GetExtension(dialog.FileName).ToLower().Trim() == ".json")
+                {
+                    this.queueProcessor.ExportJson(dialog.FileName);
+                }
+                else
+                {
+                    this.queueProcessor.BackupQueue(dialog.FileName);
+                }
+            }
         }
 
         /// <summary>
@@ -330,10 +416,11 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void Import()
         {
-            VistaOpenFileDialog dialog = new VistaOpenFileDialog { Filter = "HandBrake Queue Files (*.hbq)|*.hbq", CheckFileExists = true };
-            dialog.ShowDialog();
-
-            this.queueProcessor.RestoreQueue(dialog.FileName);
+            OpenFileDialog dialog = new OpenFileDialog { Filter = "Legacy Queue Files (*.hbq)|*.hbq", CheckFileExists = true };
+            if (dialog.ShowDialog() == true)
+            {
+                this.queueProcessor.RestoreQueue(dialog.FileName);
+            }
         }
 
         /// <summary>
@@ -345,9 +432,9 @@ namespace HandBrakeWPF.ViewModels
         public void EditJob(QueueTask task)
         {
             MessageBoxResult result = this.errorService.ShowMessageBox(
-                "Are you sure you wish to edit this job? It will be removed from the queue and sent to the main window.",
-                "Modify Job?",
-                MessageBoxButton.YesNo,
+                Resources.QueueViewModel_EditConfrimation, 
+                "Modify Job?", 
+                MessageBoxButton.YesNo, 
                 MessageBoxImage.Question);
 
             if (result != MessageBoxResult.Yes)
@@ -367,6 +454,21 @@ namespace HandBrakeWPF.ViewModels
 
         #region Methods
 
+        public void Activate()
+        {
+            this.queueProcessor.QueueCompleted += this.queueProcessor_QueueCompleted;
+            this.queueProcessor.QueueChanged += this.QueueManager_QueueChanged;
+            this.queueProcessor.JobProcessingStarted += this.QueueProcessorJobProcessingStarted;
+
+        }
+
+        public void Deactivate()
+        {
+            this.queueProcessor.QueueCompleted -= this.queueProcessor_QueueCompleted;
+            this.queueProcessor.QueueChanged -= this.QueueManager_QueueChanged;
+            this.queueProcessor.JobProcessingStarted -= this.QueueProcessorJobProcessingStarted;
+        }
+
         /// <summary>
         /// Override the OnActive to run the Screen Loading code in the view model base.
         /// </summary>
@@ -374,13 +476,15 @@ namespace HandBrakeWPF.ViewModels
         {
             this.Load();
 
-            this.WhenDoneAction = this.userSettingService.GetUserSetting<string>(ASUserSettingConstants.WhenCompleteAction);
-
-            this.queueProcessor.JobProcessingStarted += this.queueProcessor_JobProcessingStarted;
             this.queueProcessor.QueueCompleted += this.queueProcessor_QueueCompleted;
-            this.queueProcessor.QueuePaused += this.queueProcessor_QueuePaused;
             this.queueProcessor.QueueChanged += this.QueueManager_QueueChanged;
             this.queueProcessor.EncodeService.EncodeStatusChanged += this.EncodeService_EncodeStatusChanged;
+            this.queueProcessor.EncodeService.EncodeCompleted += this.EncodeService_EncodeCompleted;
+            this.queueProcessor.JobProcessingStarted += this.QueueProcessorJobProcessingStarted;
+            this.queueProcessor.LowDiskspaceDetected += this.QueueProcessor_LowDiskspaceDetected;
+
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
+            this.JobStatus = Resources.QueueViewModel_QueueReady;
 
             base.OnActivate();
         }
@@ -393,11 +497,12 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         protected override void OnDeactivate(bool close)
         {
-            this.queueProcessor.JobProcessingStarted -= this.queueProcessor_JobProcessingStarted;
             this.queueProcessor.QueueCompleted -= this.queueProcessor_QueueCompleted;
-            this.queueProcessor.QueuePaused -= this.queueProcessor_QueuePaused;
             this.queueProcessor.QueueChanged -= this.QueueManager_QueueChanged;
             this.queueProcessor.EncodeService.EncodeStatusChanged -= this.EncodeService_EncodeStatusChanged;
+            this.queueProcessor.EncodeService.EncodeCompleted -= this.EncodeService_EncodeCompleted;
+            this.queueProcessor.JobProcessingStarted -= this.QueueProcessorJobProcessingStarted;
+            this.queueProcessor.LowDiskspaceDetected -= this.QueueProcessor_LowDiskspaceDetected;
 
             base.OnDeactivate(close);
         }
@@ -411,28 +516,46 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="e">
         /// The EncodeProgressEventArgs.
         /// </param>
-        private void EncodeService_EncodeStatusChanged(
-            object sender, EncodeProgressEventArgs e)
+        private void EncodeService_EncodeStatusChanged(object sender, EncodeProgressEventArgs e)
         {
-            Caliburn.Micro.Execute.OnUIThread(() =>
+            Execute.OnUIThread(() =>
             {
-                if (this.IsEncoding)
-                {
-                    this.JobStatus =
-                        string.Format(
-                            "Encoding: Pass {0} of {1},  {2:00.00}%, FPS: {3:000.0},  Avg FPS: {4:000.0},  Time Remaining: {5},  Elapsed: {6:hh\\:mm\\:ss}",
-                            e.Task,
-                            e.TaskCount,
-                            e.PercentComplete,
-                            e.CurrentFrameRate,
-                            e.AverageFrameRate,
-                            e.EstimatedTimeLeft,
-                            e.ElapsedTime);
-                }
-
+                this.JobStatus =
+                    string.Format(
+                        Resources.QueueViewModel_QueueStatusDisplay, 
+                        e.Task, 
+                        e.TaskCount, 
+                        e.PercentComplete, 
+                        e.CurrentFrameRate, 
+                        e.AverageFrameRate, 
+                        e.EstimatedTimeLeft, 
+                        e.ElapsedTime);
             });
         }
 
+        /// <summary>
+        /// Detect Low Disk Space before starting new queue tasks.
+        /// </summary>
+        /// <param name="sender">Event invoker. </param>
+        /// <param name="e">Event Args.</param>
+        private void QueueProcessor_LowDiskspaceDetected(object sender, EventArgs e)
+        {
+            Execute.OnUIThreadAsync(
+                () =>
+                {
+                    this.queueProcessor.Pause();
+                    this.JobStatus = Resources.QueueViewModel_QueuePending;
+                    this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
+                    this.IsQueueRunning = false;
+
+                    this.errorService.ShowMessageBox(
+                        Resources.MainViewModel_LowDiskSpaceWarning,
+                        Resources.MainViewModel_LowDiskSpace,
+                        MessageBoxButton.OK,
+                        MessageBoxImage.Warning);
+                });
+        }
+
         /// <summary>
         /// Handle the Queue Changed Event.
         /// </summary>
@@ -444,24 +567,13 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         private void QueueManager_QueueChanged(object sender, EventArgs e)
         {
-            this.JobsPending = string.Format("{0} jobs pending", this.queueProcessor.Count);
-        }
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
 
-        /// <summary>
-        /// Handle teh Job Processing Started Event
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The QueueProgressEventArgs.
-        /// </param>
-        private void queueProcessor_JobProcessingStarted(
-            object sender, QueueProgressEventArgs e)
-        {
-            this.JobStatus = "Queue Started";
-            this.JobsPending = string.Format("{0} jobs pending", this.queueProcessor.Count);
-            this.IsEncoding = true;
+            if (!queueProcessor.IsProcessing)
+            {
+                this.JobStatus = Resources.QueueViewModel_QueueNotRunning;
+                this.IsQueueRunning = false;
+            }
         }
 
         /// <summary>
@@ -475,25 +587,42 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         private void queueProcessor_QueueCompleted(object sender, EventArgs e)
         {
-            this.JobStatus = "Queue Completed";
-            this.JobsPending = string.Format("{0} jobs pending", this.queueProcessor.Count);
-            this.IsEncoding = false;
+            this.JobStatus = Resources.QueueViewModel_QueueCompleted;
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
+            this.IsQueueRunning = false;
         }
 
         /// <summary>
-        /// Handle the Queue Paused Event
+        /// The encode service_ encode completed.
         /// </summary>
         /// <param name="sender">
         /// The sender.
         /// </param>
         /// <param name="e">
-        /// The EventArgs.
+        /// The e.
         /// </param>
-        private void queueProcessor_QueuePaused(object sender, EventArgs e)
+        private void EncodeService_EncodeCompleted(object sender, EncodeCompletedEventArgs e)
         {
-            this.JobStatus = "Queue Paused";
-            this.JobsPending = string.Format("{0} jobs pending", this.queueProcessor.Count);
-            this.IsEncoding = false;
+            if (!this.queueProcessor.IsProcessing)
+            {
+                this.JobStatus = Resources.QueueViewModel_LastJobFinished;
+            }
+        }
+
+        /// <summary>
+        /// The queue processor job processing started.
+        /// </summary>
+        /// <param name="sender">
+        /// The sender.
+        /// </param>
+        /// <param name="e">
+        /// The QueueProgressEventArgs.
+        /// </param>
+        private void QueueProcessorJobProcessingStarted(object sender, QueueProgressEventArgs e)
+        {
+            this.JobStatus = Resources.QueueViewModel_QueueStarted;
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
+            this.IsQueueRunning = true; 
         }
 
         #endregion
