@@ -13,13 +13,13 @@ namespace HandBrakeWPF.ViewModels
 
     using Caliburn.Micro;
 
-    using HandBrake.ApplicationServices.Services.Interfaces;
-
     using HandBrakeWPF.Model;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.ViewModels.Interfaces;
 
+    using IQueueProcessor = HandBrakeWPF.Services.Queue.Interfaces.IQueueProcessor;
+
     /// <summary>
     /// The Shell View Model
     /// </summary>
@@ -42,10 +42,7 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         private bool showOptions;
 
-        /// <summary>
-        /// The show instant.
-        /// </summary>
-        private bool showInstant;
+        private bool isMainPanelEnabled;
 
         #endregion
 
@@ -55,22 +52,20 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="errorService">
         /// The error Service.
         /// </param>
-        public ShellViewModel(IErrorService errorService)
+        /// <param name="mainViewModel">
+        /// The main View Model.
+        /// </param>
+        /// <param name="optionsViewModel">
+        /// The options View Model.
+        /// </param>
+        public ShellViewModel(IErrorService errorService, IMainViewModel mainViewModel, IOptionsViewModel optionsViewModel)
         {
             this.errorService = errorService;
-
-            if (!AppArguments.IsInstantHandBrake)
-            {
-                this.showMainWindow = true;
-                this.showOptions = false;
-                this.showInstant = false;
-            }
-            else
-            {
-                this.showMainWindow = false;
-                this.showOptions = false;
-                this.showInstant = true;
-            }
+            this.showMainWindow = true;
+            this.showOptions = false;
+            this.IsMainPanelEnabled = true;
+            this.MainViewModel = mainViewModel;
+            this.OptionsViewModel = optionsViewModel;
         }
 
         /// <summary>
@@ -85,25 +80,16 @@ namespace HandBrakeWPF.ViewModels
             {
                 this.ShowMainWindow = true;
                 this.ShowOptions = false;
-                this.ShowInstant = false;
             }
             else if (window == ShellWindow.OptionsWindow)
             {
                 this.ShowOptions = true;
                 this.ShowMainWindow = false;
-                this.ShowInstant = false;
-            }
-            else if (window == ShellWindow.InstantMainWindow)
-            {
-                this.ShowInstant = true;
-                this.ShowOptions = false;
-                this.ShowMainWindow = false;
             }
             else
             {
                 this.ShowMainWindow = true;
                 this.ShowOptions = false;
-                this.ShowInstant = false;
             }
         }
 
@@ -119,11 +105,6 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public IOptionsViewModel OptionsViewModel { get; set; }
 
-        /// <summary>
-        /// Gets or sets the instant view model.
-        /// </summary>
-        public IInstantViewModel InstantViewModel { get; set; }
-
         /// <summary>
         /// Gets or sets a value indicating whether ShowMainWindow.
         /// </summary>
@@ -157,18 +138,22 @@ namespace HandBrakeWPF.ViewModels
         }
 
         /// <summary>
-        /// Gets or sets a value indicating whether ShowInstant.
+        /// Gets or sets a value indicating whether is main panel enabled.
         /// </summary>
-        public bool ShowInstant
+        public bool IsMainPanelEnabled
         {
             get
             {
-                return this.showInstant;
+                return this.isMainPanelEnabled;
             }
             set
             {
-                this.showInstant = value;
-                this.NotifyOfPropertyChange(() => this.ShowInstant);
+                if (value.Equals(this.isMainPanelEnabled))
+                {
+                    return;
+                }
+                this.isMainPanelEnabled = value;
+                this.NotifyOfPropertyChange(() => this.IsMainPanelEnabled);
             }
         }
 
@@ -179,12 +164,23 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return AppArguments.IsInstantHandBrake ? "Instant HandBrake" : "HandBrake";
+                return "HandBrake";
             }
         }
 
         #endregion
 
+        /// <summary>
+        /// The files dropped on window. Pass this through to the active view model.
+        /// </summary>
+        /// <param name="e">
+        /// The DragEventArgs.
+        /// </param>
+        public void FilesDroppedOnWindow(DragEventArgs e)
+        {
+            this.MainViewModel.FilesDroppedOnWindow(e);
+        }
+
         /// <summary>
         /// Checks with the use if this window can be closed.
         /// </summary>
@@ -198,7 +194,7 @@ namespace HandBrakeWPF.ViewModels
             {
                 MessageBoxResult result =
                     errorService.ShowMessageBox(
-                        "An Encode is currently running. Exiting HandBrake will stop this encode.\nAre you sure you wish to exit HandBrake?",
+                        Resources.ShellViewModel_CanClose,
                         Resources.Warning,
                         MessageBoxButton.YesNo,
                         MessageBoxImage.Warning);
