@@ -14,48 +14,36 @@ namespace HandBrakeWPF.ViewModels
     using System.IO;
     using System.Linq;
 
-    using HandBrake.ApplicationServices.Model;
-    using HandBrake.ApplicationServices.Model.Encoding;
-    using HandBrake.ApplicationServices.Model.Subtitle;
-    using HandBrake.ApplicationServices.Parsing;
+    using Caliburn.Micro;
+
     using HandBrake.ApplicationServices.Utilities;
 
+    using HandBrakeWPF.Model.Subtitles;
+    using HandBrakeWPF.Properties;
+    using HandBrakeWPF.Services.Presets.Model;
+    using HandBrakeWPF.Services.Scan.Model;
+    using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
 
-    using Ookii.Dialogs.Wpf;
+    using Microsoft.Win32;
+
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
+    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
+    using SubtitleTrack = HandBrakeWPF.Services.Encode.Model.Models.SubtitleTrack;
+    using SubtitleType = HandBrakeWPF.Services.Encode.Model.Models.SubtitleType;
 
     /// <summary>
     /// The Subtitles View Model
     /// </summary>
     public class SubtitlesViewModel : ViewModelBase, ISubtitlesViewModel
     {
+        private readonly IWindowManager windowManager;
+
         #region Constants and Fields
 
-        /// <summary>
-        /// The Foreign Audio Search Track
-        /// </summary>
         private readonly Subtitle ForeignAudioSearchTrack;
-
-        /// <summary>
-        /// Backing field for the source subtitle tracks.
-        /// </summary>
         private IList<Subtitle> sourceTracks;
 
-        /// <summary>
-        /// The show defaults panel.
-        /// </summary>
-        private bool showDefaultsPanel;
-
-        /// <summary>
-        /// The audio behaviours.
-        /// </summary>
-        private SubtitleBehaviours subtitleBehaviours;
-
-        /// <summary>
-        /// The available languages.
-        /// </summary>
-        private BindingList<string> availableLanguages;
-
         #endregion
 
         #region Constructors and Destructors
@@ -63,8 +51,13 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Initializes a new instance of the <see cref="HandBrakeWPF.ViewModels.SubtitlesViewModel"/> class.
         /// </summary>
-        public SubtitlesViewModel()
+        /// <param name="windowManager">
+        /// The window Manager.
+        /// </param>
+        public SubtitlesViewModel(IWindowManager windowManager)
         {
+            this.windowManager = windowManager;
+            this.SubtitleDefaultsViewModel = new SubtitlesDefaultsViewModel();
             this.Task = new EncodeTask();
 
             this.Langauges = LanguageUtilities.MapLanguages().Keys;
@@ -72,18 +65,17 @@ namespace HandBrakeWPF.ViewModels
 
             this.ForeignAudioSearchTrack = new Subtitle { SubtitleType = SubtitleType.ForeignAudioSearch, Language = "Foreign Audio Search (Bitmap)" };
             this.SourceTracks = new List<Subtitle> { this.ForeignAudioSearchTrack };
-
-            this.SubtitleBehaviours = new SubtitleBehaviours();
-            this.SelectedAvailableToMove = new BindingList<string>();
-            this.SelectedLangaugesToMove = new BindingList<string>();
-            this.availableLanguages = new BindingList<string>();
-            this.SetupLanguages(null);
         }
 
         #endregion
 
         #region Properties
 
+        /// <summary>
+        /// Gets or sets the audio defaults view model.
+        /// </summary>
+        public ISubtitlesDefaultsViewModel SubtitleDefaultsViewModel { get; set; }
+
         /// <summary>
         /// Gets or sets CharacterCodes.
         /// </summary>
@@ -116,28 +108,6 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public EncodeTask Task { get; set; }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether show defaults panel.
-        /// </summary>
-        public bool ShowDefaultsPanel
-        {
-            get
-            {
-                return this.showDefaultsPanel;
-            }
-            set
-            {
-                if (value.Equals(this.showDefaultsPanel))
-                {
-                    return;
-                }
-                this.showDefaultsPanel = value;
-                this.NotifyOfPropertyChange(() => this.ShowDefaultsPanel);
-                this.NotifyOfPropertyChange(() => this.PanelTitle);
-                this.NotifyOfPropertyChange(() => this.SwitchDisplayTitle);
-            }
-        }
-
         /// <summary>
         /// Gets the panel title.
         /// </summary>
@@ -145,7 +115,7 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return this.ShowDefaultsPanel ? "Subtitle Defaults" : "Subtitle Tracks";
+                return Resources.SubtitlesViewModel_SubTracks;
             }
         }
 
@@ -156,68 +126,21 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return this.ShowDefaultsPanel ? "Switch to Tracks" : "Switch to Defaults";
+                return Resources.SubtitlesViewModel_ConfigureDefaults;
             }
         }
 
         /// <summary>
-        /// Gets or sets the subtitle behaviours.
+        /// Gets the default audio behaviours. 
         /// </summary>
         public SubtitleBehaviours SubtitleBehaviours
         {
             get
             {
-                return this.subtitleBehaviours;
-            }
-            set
-            {
-                if (Equals(value, this.subtitleBehaviours))
-                {
-                    return;
-                }
-                this.subtitleBehaviours = value;
-                this.NotifyOfPropertyChange(() => this.SubtitleBehaviours);
+                return this.SubtitleDefaultsViewModel.SubtitleBehaviours;
             }
         }
 
-        /// <summary>
-        /// Gets the sbutitle behaviour modes.
-        /// </summary>
-        public BindingList<SubtitleBehaviourModes> SubtitleBehaviourModeList
-        {
-            get
-            {
-                return new BindingList<SubtitleBehaviourModes>(EnumHelper<SubtitleBehaviourModes>.GetEnumList().ToList());
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets AvailableLanguages.
-        /// </summary>
-        public BindingList<string> AvailableLanguages
-        {
-            get
-            {
-                return this.availableLanguages;
-            }
-
-            set
-            {
-                this.availableLanguages = value;
-                this.NotifyOfPropertyChange("AvailableLanguages");
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets SelectedLangauges.
-        /// </summary>
-        public BindingList<string> SelectedAvailableToMove { get; set; }
-
-        /// <summary>
-        /// Gets or sets SelectedLangauges.
-        /// </summary>
-        public BindingList<string> SelectedLangaugesToMove { get; set; }
-
         #endregion
 
         #region Public Methods
@@ -311,7 +234,7 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void Import()
         {
-            VistaOpenFileDialog dialog = new VistaOpenFileDialog
+            OpenFileDialog dialog = new OpenFileDialog
                 {
                     Filter = "SRT files (*.srt)|*.srt",
                     CheckFileExists = true,
@@ -417,6 +340,76 @@ namespace HandBrakeWPF.ViewModels
                     break;
             }
 
+            // Burn In Behaviour
+            if (this.Task.SubtitleTracks.Count >= 1)
+            {
+                bool burnInSet = false;
+                switch (this.SubtitleBehaviours.SelectedBurnInBehaviour)
+                {
+                    case SubtitleBurnInBehaviourModes.None:
+                        foreach (var track in this.Task.SubtitleTracks)
+                        {
+                            if (track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch)
+                            {
+                                track.Forced = true;
+                                break;
+                            }
+                        }
+                        break;
+                    case SubtitleBurnInBehaviourModes.ForeignAudio:
+                        foreach (var track in this.Task.SubtitleTracks)
+                        {
+                            // Set the Foreign Audio Track to burned-in
+                            if (track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch)
+                            {
+                                track.Burned = true;
+                                track.Forced = true;
+                                this.SetBurnedToFalseForAllExcept(track);
+                                break;
+                            }
+                        }
+                        break;
+                    case SubtitleBurnInBehaviourModes.FirstTrack:                    
+                        foreach (var track in this.Task.SubtitleTracks)
+                        {
+                            if (track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch) // Foreign Audio Search is always first in the list.
+                            {
+                                track.Forced = true;
+                                continue;
+                            }
+
+                            if (!burnInSet)
+                            {
+                                burnInSet = true;
+                                track.Burned = true;
+                                this.SetBurnedToFalseForAllExcept(track);
+                            }
+                        }                  
+                        break;
+                    case SubtitleBurnInBehaviourModes.ForeignAudioPreferred:
+                        foreach (var track in this.Task.SubtitleTracks)
+                        {
+                            // Set the first track.
+                            if (!burnInSet)
+                            {
+                                burnInSet = true;
+                                track.Burned = true;
+                                this.SetBurnedToFalseForAllExcept(track);
+                            }
+
+                            // But if there is a foreign audio track, prefer this to the first.
+                            if (track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch)
+                            {
+                                track.Burned = true;
+                                track.Forced = true;
+                                this.SetBurnedToFalseForAllExcept(track);
+                                break;
+                            }
+                        }            
+                        break;
+                }
+            }
+
             // Add all closed captions if enabled.
             if (this.SubtitleBehaviours.AddClosedCaptions)
             {
@@ -424,70 +417,28 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Open the options screen to the Audio and Subtitles tab.
-        /// </summary>
-        public void SetDefaultBehaviour()
-        {
-            this.ShowDefaultsPanel = true;
-        }
-
         /// <summary>
         /// The show audio defaults.
         /// </summary>
         public void ShowSubtitleDefaultsPanel()
         {
-            this.ShowDefaultsPanel = !this.ShowDefaultsPanel;
-        }
-
-        /// <summary>
-        /// Audio List Move Left
-        /// </summary>
-        public void LanguageMoveRight()
-        {
-            if (this.SelectedAvailableToMove.Count > 0)
+            IPopupWindowViewModel popup = new PopupWindowViewModel(this.SubtitleDefaultsViewModel, ResourcesUI.Preset_SubtitleDefaults_Title, ResourcesUI.SubtitleView_SubtitleDefaultsDescription);
+            if (this.windowManager.ShowDialog(popup) == true)
             {
-                List<string> copiedList = SelectedAvailableToMove.ToList();
-                foreach (string item in copiedList)
-                {
-                    this.AvailableLanguages.Remove(item);
-                    this.SubtitleBehaviours.SelectedLangauges.Add(item);
-                }
-
-                this.AvailableLanguages = new BindingList<string>(this.AvailableLanguages.OrderBy(o => o).ToList());
+                // Nothing to do yet, it's by reference. 
+            }
+            else
+            {
+                // Handle other case(s)
             }
         }
 
         /// <summary>
-        /// Audio List Move Right
+        /// Reload the audio tracks based on the defaults.
         /// </summary>
-        public void LanguageMoveLeft()
+        public void ReloadDefaults()
         {
-            if (this.SelectedLangaugesToMove.Count > 0)
-            {
-                List<string> copiedList = SelectedLangaugesToMove.ToList();
-                foreach (string item in copiedList)
-                {
-                    this.SubtitleBehaviours.SelectedLangauges.Remove(item);
-                    this.AvailableLanguages.Add(item);
-                }
-            }
-
-            this.AvailableLanguages = new BindingList<string>(this.AvailableLanguages.OrderBy(o => o).ToList());
-        }
-
-        /// <summary>
-        /// Language List Clear all selected languages
-        /// </summary>
-        public void LanguageClearAll()
-        {
-            foreach (string item in this.SubtitleBehaviours.SelectedLangauges)
-            {
-                this.AvailableLanguages.Add(item);
-            }
-            this.AvailableLanguages = new BindingList<string>(this.AvailableLanguages.OrderBy(o => o).ToList());
-
-            this.SubtitleBehaviours.SelectedLangauges.Clear();
+            this.AutomaticSubtitleSelection();
         }
 
         #endregion
@@ -509,7 +460,7 @@ namespace HandBrakeWPF.ViewModels
             this.Task = task;
             this.NotifyOfPropertyChange(() => this.Task);
 
-            this.SetupLanguages(preset);
+            this.SubtitleDefaultsViewModel.SetupLanguages(preset);
             this.AutomaticSubtitleSelection();
         }
 
@@ -529,6 +480,9 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Setup this window for a new source
         /// </summary>
+        /// <param name="source">
+        /// The source.
+        /// </param>
         /// <param name="title">
         /// The title.
         /// </param>
@@ -538,7 +492,7 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="task">
         /// The task.
         /// </param>
-        public void SetSource(Title title, Preset preset, EncodeTask task)
+        public void SetSource(Source source, Title title, Preset preset, EncodeTask task)
         {
             this.SourceTracks.Clear();
             this.SourceTracks.Add(ForeignAudioSearchTrack);
@@ -588,9 +542,19 @@ namespace HandBrakeWPF.ViewModels
                                           SourceTrack = source,
                                       };
 
-            if ((source.SubtitleType == SubtitleType.PGS || source.SubtitleType == SubtitleType.VobSub || source.SubtitleType == SubtitleType.ForeignAudioSearch)
-                && this.Task != null
-                && this.Task.OutputFormat == OutputFormat.Mp4)
+            // Burn-in Behaviours
+            if (this.SubtitleBehaviours.SelectedBurnInBehaviour == SubtitleBurnInBehaviourModes.ForeignAudio
+                  || this.SubtitleBehaviours.SelectedBurnInBehaviour == SubtitleBurnInBehaviourModes.ForeignAudioPreferred)
+            {
+                if (subtitle != null && subtitle.SubtitleType == SubtitleType.ForeignAudioSearch)
+                {
+                    track.Burned = true;
+                    this.SetBurnedToFalseForAllExcept(track);
+                }
+            }
+
+            // For MP4, PGS Subtitles must be burned in.
+            if (!track.Burned && (source.SubtitleType == SubtitleType.PGS) && this.Task != null && this.Task.OutputFormat == OutputFormat.Mp4)
             {
                 if (track.CanBeBurned)
                 {
@@ -656,45 +620,6 @@ namespace HandBrakeWPF.ViewModels
                        : this.SourceTracks.Where(subtitle => !this.Task.SubtitleTracks.Any(track => Equals(track.SourceTrack, subtitle))).ToList();
         }
 
-        /// <summary>
-        /// The setup languages.
-        /// </summary>
-        /// <param name="preset">
-        /// The preset.
-        /// </param>
-        private void SetupLanguages(Preset preset)
-        {
-            // Step 1, Set the behaviour mode
-            this.SubtitleBehaviours.SelectedBehaviour = SubtitleBehaviourModes.None;
-            this.SubtitleBehaviours.AddClosedCaptions = false;
-            this.SubtitleBehaviours.AddForeignAudioScanTrack = false;
-            this.SubtitleBehaviours.SelectedLangauges.Clear();
-
-            // Step 2, Get all the languages
-            IDictionary<string, string> langList = LanguageUtilities.MapLanguages();
-            langList = (from entry in langList orderby entry.Key ascending select entry).ToDictionary(pair => pair.Key, pair => pair.Value);
-
-            // Step 3, Setup Available Languages
-            this.AvailableLanguages.Clear();
-            foreach (string item in langList.Keys)
-            {
-                this.AvailableLanguages.Add(item);
-            }
-
-            // Step 4, Set the Selected Languages        
-            if (preset != null && preset.SubtitleTrackBehaviours != null)
-            {
-                this.SubtitleBehaviours.SelectedBehaviour = preset.SubtitleTrackBehaviours.SelectedBehaviour;
-                this.SubtitleBehaviours.AddClosedCaptions = preset.SubtitleTrackBehaviours.AddClosedCaptions;
-                this.SubtitleBehaviours.AddForeignAudioScanTrack = preset.SubtitleTrackBehaviours.AddForeignAudioScanTrack;
-
-                foreach (string selectedItem in preset.SubtitleTrackBehaviours.SelectedLangauges)
-                {
-                    this.AvailableLanguages.Remove(selectedItem);
-                    this.SubtitleBehaviours.SelectedLangauges.Add(selectedItem);
-                }
-            }
-        }
         #endregion
     }
 }
\ No newline at end of file
