@@ -11,8 +11,6 @@ namespace HandBrakeWPF.ViewModels
 {
     using Caliburn.Micro;
 
-    using HandBrakeWPF.Helpers;
-    using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     /// <summary>
@@ -64,27 +62,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets a value indicating whether use system colours.
-        /// </summary>
-        public bool UseSystemColours
-        {
-            get
-            {
-                return AppStyleHelper.UseSystemColours;
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets WindowManager.
-        /// </summary>
-        public IWindowManager WindowManager { get; set; }
-
-        /// <summary>
-        /// Gets or sets UserSettingService.
-        /// </summary>
-        public IUserSettingService UserSettingService { get; set; }
-
         #endregion
 
         #region Public Methods
