@@ -14,25 +14,21 @@ namespace HandBrakeWPF.ViewModels
     using System.Globalization;
     using System.Linq;
 
-    using HandBrake.ApplicationServices.Model;
-    using HandBrake.ApplicationServices.Parsing;
-    using HandBrake.Interop.Model.Encoding;
+    using HandBrake.ApplicationServices.Interop.Model.Encoding;
 
-    using HandBrakeWPF.Commands.Interfaces;
     using HandBrakeWPF.Helpers;
     using HandBrakeWPF.Model;
+    using HandBrakeWPF.Services.Presets.Model;
+    using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.ViewModels.Interfaces;
 
+    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
+
     /// <summary>
     /// The Advanced View Model
     /// </summary>
     public class X264ViewModel : ViewModelBase, IX264ViewModel
     {
-        /// <summary>
-        /// The advanced encoder options command.
-        /// </summary>
-        private readonly IAdvancedEncoderOptionsCommand advancedEncoderOptionsCommand;
-
         #region Constants and Fields
 
         /// <summary>
@@ -162,12 +158,8 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Initializes a new instance of the <see cref="X264ViewModel"/> class.
         /// </summary>
-        /// <param name="advancedEncoderOptionsCommand">
-        /// The advanced Encoder Options Command.
-        /// </param>
-        public X264ViewModel(IAdvancedEncoderOptionsCommand advancedEncoderOptionsCommand)
+        public X264ViewModel()
         {
-            this.advancedEncoderOptionsCommand = advancedEncoderOptionsCommand;
             this.Task = new EncodeTask();
             this.UpdateUIFromAdvancedOptions();
         }
@@ -188,6 +180,11 @@ namespace HandBrakeWPF.ViewModels
                 ShowX264AdvancedOptions = this.Task.ShowAdvancedTab;
                 this.NotifyOfPropertyChange(() => ShowX264AdvancedOptions);
                 this.NotifyOfPropertyChange(() => this.AdvancedOptionsString);
+
+                if (ShowX264AdvancedOptions)
+                {
+                    this.UpdateUIFromAdvancedOptions();
+                }
             }
         }
 
@@ -251,12 +248,6 @@ namespace HandBrakeWPF.ViewModels
                 this.Task.AdvancedEncoderOptions = value;
                 this.UpdateUIFromAdvancedOptions();
                 this.NotifyOfPropertyChange(() => this.AdvancedOptionsString);
-
-                // Reset the video tab if the user is using this tab.
-                if (!string.IsNullOrEmpty(this.Task.AdvancedEncoderOptions))
-                {
-                    this.advancedEncoderOptionsCommand.ExecuteClearVideo();
-                }
             }
         }
 
@@ -942,6 +933,12 @@ namespace HandBrakeWPF.ViewModels
             this.Task = task;
             this.Task.PropertyChanged += this.Task_PropertyChanged;
             this.AdvancedOptionsString = preset.Task.AdvancedEncoderOptions;
+
+            if (task.ShowAdvancedTab && (task.VideoEncoder == VideoEncoder.X264 || task.VideoEncoder == VideoEncoder.X264_10))
+            {
+                this.ShowX264AdvancedOptions = true;
+                this.NotifyOfPropertyChange(() => ShowX264AdvancedOptions);
+            }
         }
 
         /// <summary>
@@ -960,6 +957,9 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Setup this window for a new source
         /// </summary>
+        /// <param name="source">
+        /// The source.
+        /// </param>
         /// <param name="title">
         /// The title.
         /// </param>
@@ -969,7 +969,7 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="task">
         /// The task.
         /// </param>
-        public void SetSource(Title title, Preset preset, EncodeTask task)
+        public void SetSource(Source source, Title title, Preset preset, EncodeTask task)
         {
             this.Task = task;
             this.NotifyOfPropertyChange(() => this.AdvancedOptionsString);
@@ -1143,12 +1143,6 @@ namespace HandBrakeWPF.ViewModels
 
             this.Task.AdvancedEncoderOptions = string.Join(":", newOptions);
             this.NotifyOfPropertyChange(() => this.AdvancedOptionsString);
-
-            // Reset the video tab if the user is using this tab.
-            if (!string.IsNullOrEmpty(this.Task.AdvancedEncoderOptions))
-            {
-                this.advancedEncoderOptionsCommand.ExecuteClearVideo();
-            }
         }
 
         #endregion
