@@ -4,12 +4,14 @@
 // </copyright>
 // <summary>
 //   Interaction logic for ShellView.xaml
-// </summary> 
+// </summary>
 // --------------------------------------------------------------------------------------------------------------------
 
 namespace HandBrakeWPF.Views
 {
     using System;
+    using System.ComponentModel;
+    using System.Drawing;
     using System.IO;
     using System.Windows;
     using System.Windows.Forms;
@@ -18,14 +20,13 @@ namespace HandBrakeWPF.Views
 
     using Caliburn.Micro;
 
-    using HandBrake.ApplicationServices.Services.Interfaces;
-    using HandBrake.ApplicationServices.Utilities;
-
     using HandBrakeWPF.Commands;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     using Application = System.Windows.Application;
+    using Execute = Caliburn.Micro.Execute;
 
     /// <summary>
     /// Interaction logic for ShellView.xaml
@@ -35,7 +36,7 @@ namespace HandBrakeWPF.Views
         /// <summary>
         /// The my notify icon.
         /// </summary>
-        private readonly System.Windows.Forms.NotifyIcon notifyIcon;
+        private readonly NotifyIcon notifyIcon;
 
         /// <summary>
         /// Initializes a new instance of the <see cref="ShellView"/> class.
@@ -49,51 +50,56 @@ namespace HandBrakeWPF.Views
 
             if (minimiseToTray)
             {
-                this.notifyIcon = new System.Windows.Forms.NotifyIcon();
-                this.notifyIcon.ContextMenu = new ContextMenu(new[] { new MenuItem("Restore", NotifyIconClick) });
+                this.notifyIcon = new NotifyIcon();
+                this.notifyIcon.ContextMenu = new ContextMenu(new[] { new MenuItem("Restore", NotifyIconClick), new MenuItem("Mini Status Display", ShowMiniStatusDisplay) });
 
                 StreamResourceInfo streamResourceInfo = Application.GetResourceStream(new Uri("pack://application:,,,/handbrakepineapple.ico"));
                 if (streamResourceInfo != null)
                 {
                     Stream iconStream = streamResourceInfo.Stream;
-                    this.notifyIcon.Icon = new System.Drawing.Icon(iconStream);
+                    this.notifyIcon.Icon = new Icon(iconStream);
                 }
                 this.notifyIcon.DoubleClick += this.NotifyIconClick;
                 this.StateChanged += this.ShellViewStateChanged;
             }
 
-            // Start Encode (Ctrl+S)
-            // Stop Encode (Ctrl+K)
-            // Open Log Window (Ctrl+L)
-            // Open Queue Window (Ctrl+Q)
-            // Add to Queue (Ctrl+A)
-            // Scan a File (Ctrl+F)
-            // Scan a Folder (Ctrl+R)
-            // Show CLI Query (Ctrl+Shift+D)
-
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.S, ModifierKeys.Control)), new KeyGesture(Key.S, ModifierKeys.Control)));
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.K, ModifierKeys.Control)), new KeyGesture(Key.K, ModifierKeys.Control)));
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.L, ModifierKeys.Control)), new KeyGesture(Key.L, ModifierKeys.Control)));
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.Q, ModifierKeys.Control)), new KeyGesture(Key.Q, ModifierKeys.Control)));
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.A, ModifierKeys.Control)), new KeyGesture(Key.A, ModifierKeys.Control)));
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.F, ModifierKeys.Control)), new KeyGesture(Key.F, ModifierKeys.Control)));
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.O, ModifierKeys.Control)), new KeyGesture(Key.O, ModifierKeys.Control)));
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.R, ModifierKeys.Control)), new KeyGesture(Key.R, ModifierKeys.Control)));
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.D, ModifierKeys.Control | ModifierKeys.Shift)), new KeyGesture(Key.D, ModifierKeys.Control | ModifierKeys.Shift)));
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.S, ModifierKeys.Control)), new KeyGesture(Key.S, ModifierKeys.Control))); // Start Encode
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.K, ModifierKeys.Control)), new KeyGesture(Key.K, ModifierKeys.Control))); // Stop Encode
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.L, ModifierKeys.Control)), new KeyGesture(Key.L, ModifierKeys.Control))); // Open Log Window
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.Q, ModifierKeys.Control)), new KeyGesture(Key.Q, ModifierKeys.Control))); // Open Queue Window
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.A, ModifierKeys.Control)), new KeyGesture(Key.A, ModifierKeys.Control))); // Add to Queue
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.O, ModifierKeys.Control)), new KeyGesture(Key.O, ModifierKeys.Control))); // File Scan
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.O, ModifierKeys.Alt)), new KeyGesture(Key.O, ModifierKeys.Alt)));     // Scan Window
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.O, ModifierKeys.Control | ModifierKeys.Shift)), new KeyGesture(Key.O, ModifierKeys.Control | ModifierKeys.Shift))); // Scan a Folder
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.G, ModifierKeys.Control | ModifierKeys.Shift)), new KeyGesture(Key.G, ModifierKeys.Control | ModifierKeys.Shift))); // Garbage Colleciton
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.F1, ModifierKeys.None)), new KeyGesture(Key.F1, ModifierKeys.None))); // Help
 
             // Enable Windows 7 Taskbar progress indication.
             if (this.TaskbarItemInfo == null)
             {
                 this.TaskbarItemInfo = Win7.WindowsTaskbar;
             }
+        }
 
-            // Window Sizing
-            if (AppArguments.IsInstantHandBrake)
-            {
-                this.SizeToContent = SizeToContent.WidthAndHeight;
-                this.MinHeight = 380;
-                this.MinWidth = 600;
-            }
+        /// <summary>
+        /// The show mini status display.
+        /// </summary>
+        /// <param name="sender">
+        /// The sender.
+        /// </param>
+        /// <param name="e">
+        /// The e.
+        /// </param>
+        private void ShowMiniStatusDisplay(object sender, EventArgs e)
+        {
+            IMiniViewModel titleSpecificView = IoC.Get<IMiniViewModel>();
+            IWindowManager windowManager = IoC.Get<IWindowManager>();
+            Execute.OnUIThread(
+                () =>
+                {
+                    titleSpecificView.Activate();
+                    windowManager.ShowWindow(titleSpecificView);
+                });
         }
 
         /// <summary>
@@ -127,6 +133,7 @@ namespace HandBrakeWPF.Views
                 {
                     this.ShowInTaskbar = false;
                     notifyIcon.Visible = true;
+
                     // notifyIcon.ShowBalloonTip(5000, "HandBrake", "Application Minimised", ToolTipIcon.Info);          
                 }
                 else if (this.WindowState == WindowState.Normal)
@@ -143,7 +150,7 @@ namespace HandBrakeWPF.Views
         /// <param name="e">
         /// The CancelEventArgs.
         /// </param>
-        protected override void OnClosing(System.ComponentModel.CancelEventArgs e)
+        protected override void OnClosing(CancelEventArgs e)
         {
             IShellViewModel shellViewModel = this.DataContext as IShellViewModel;
 
